<?php

$LANG = array(
    'organization' => 'Entreprise',
    'name' => 'Nom',
    'website' => 'Site Web',
    'work_phone' => 'Téléphone',
    'address' => 'Adresse',
    'address1' => 'Rue',
    'address2' => 'Appt/Bâtiment',
    'city' => 'Ville',
    'state' => 'Région/Département',
    'postal_code' => 'Code postal',
    'country_id' => 'Pays',
    'contacts' => 'Informations de contact',
    'first_name' => 'Prénom',
    'last_name' => 'Nom',
    'phone' => 'Téléphone',
    'email' => 'Courriel',
    'additional_info' => 'Informations complémentaires',
    'payment_terms' => 'Conditions de paiement',
    'currency_id' => 'Devise',
    'size_id' => 'Taille de l’entreprise',
    'industry_id' => 'Secteur',
    'private_notes' => 'Notes personnelles',
    'invoice' => 'Facture',
    'client' => 'Client',
    'invoice_date' => 'Date de facture',
    'due_date' => 'Date d\'échéance',
    'invoice_number' => 'Numéro de facture',
    'invoice_number_short' => 'N° Facture',
    'po_number' => 'N° de Bon de Commande',
    'po_number_short' => 'Commande',
    'frequency_id' => 'Fréquence',
    'discount' => 'Remise',
    'taxes' => 'Taxes',
    'tax' => 'Taxe',
    'item' => 'Article',
    'description' => 'Description',
    'unit_cost' => 'Coût unitaire',
    'quantity' => 'Quantité',
    'line_total' => 'Total',
    'subtotal' => 'Sous-total',
    'paid_to_date' => 'Payé à ce jour',
    'balance_due' => 'Montant dû',
    'invoice_design_id' => 'Style',
    'terms' => 'Conditions',
    'your_invoice' => 'Votre facture',
    'remove_contact' => 'Supprimer le contact',
    'add_contact' => 'Ajouter un contact',
    'create_new_client' => 'Ajouter un nouveau client',
    'edit_client_details' => 'Modifier les informations du client',
    'enable' => 'Activé(e)',
    'learn_more' => 'En savoir plus',
    'manage_rates' => 'Gérer les taux',
    'note_to_client' => 'Commentaire pour le client',
    'invoice_terms' => 'Conditions de facturation',
    'save_as_default_terms' => 'Sauvegarder comme conditions par défaut',
    'download_pdf' => 'Télécharger le PDF',
    'pay_now' => 'Payer maintenant',
    'save_invoice' => 'Sauvegarder la facture',
    'clone_invoice' => 'Dupliquer la facture',
    'archive_invoice' => 'Archiver la facture',
    'delete_invoice' => 'Supprimer la facture',
    'email_invoice' => 'Envoyer la facture par courriel',
    'enter_payment' => 'Saisissez un paiement',
    'tax_rates' => 'Taux de taxe',
    'rate' => 'Taux',
    'settings' => 'Paramètres',
    'enable_invoice_tax' => 'Spécifier une <b>taxe pour la facture</b>',
    'enable_line_item_tax' => 'Spécifier une <b>taxe pour chaque ligne</b>',
    'dashboard' => 'Tableau de bord',
    'dashboard_totals_in_all_currencies_help' => 'Note: ajoute un :link intitulé ":name" pour afficher les totaux qui utilisent une seule devise de base.',
    'clients' => 'Clients',
    'invoices' => 'Factures',
    'payments' => 'Paiements',
    'credits' => 'Crédits',
    'history' => 'Historique',
    'search' => 'Rechercher',
    'sign_up' => 'S’enregistrer',
    'guest' => 'Invité',
    'company_details' => 'Informations sur l’entreprise',
    'online_payments' => 'Paiements en ligne',
    'notifications' => 'Notifications',
    'import_export' => 'Importer/Exporter',
    'done' => 'Terminé',
    'save' => 'Sauvegarder',
    'create' => 'Créer',
    'upload' => 'Envoyer',
    'import' => 'Importer',
    'download' => 'Télécharger',
    'cancel' => 'Annuler',
    'close' => 'Fermer',
    'provide_email' => 'Veuillez renseigner une adresse courriel valide',
    'powered_by' => 'Propulsé par',
    'no_items' => 'Aucun élément',
    'recurring_invoices' => 'Factures récurrentes',
    'recurring_help' => '<p>Envoyer automatiquement la même facture à vos clients de façon hebdomadaire, bimensuelle, mensuelle, trimestrielle ou annuelle. </p>
        <p>Utiliser :MONTH, :QUARTER ou :YEAR pour des dates dynamiques. Les opérations simples fonctionnent également, par exemple :MONTH-1.</p>
        <p>Exemples de variables dynamiques pour les factures:</p>
        <ul>
          <li>"Adhésion au club de gym pour le mois de :MONTH" >> "Adhésion au club de gym pour le mois de Juillet"</li>
          <li>YEAR+1 - abonnement annuel" >> "2015 - abonnement annuel</li>
          <li>Acompte pour le :QUARTER+1" >> "Acompte pour le Q2</li>
        </ul>',
    'recurring_quotes' => 'Devis récurrent',
    'in_total_revenue' => 'de bénéfice total',
    'billed_client' => 'client facturé',
    'billed_clients' => 'clients facturés',
    'active_client' => 'client actif',
    'active_clients' => 'clients actifs',
    'invoices_past_due' => 'Date limite de paiement dépassée',
    'upcoming_invoices' => 'Factures à venir',
    'average_invoice' => 'Facture moyenne',
    'archive' => 'Archiver',
    'delete' => 'Supprimer',
    'archive_client' => 'Archiver ce client',
    'delete_client' => 'Supprimer ce client',
    'archive_payment' => 'Archiver ce paiement',
    'delete_payment' => 'Supprimer ce paiement',
    'archive_credit' => 'Archiver ce crédit',
    'delete_credit' => 'Supprimer ce crédit',
    'show_archived_deleted' => 'Afficher archivés/supprimés',
    'filter' => 'Filtrer',
    'new_client' => 'Nouveau client',
    'new_invoice' => 'Nouvelle facture',
    'new_payment' => 'Entrer un paiement',
    'new_credit' => 'Entrer un crédit',
    'contact' => 'Contact',
    'date_created' => 'Date de création',
    'last_login' => 'Dernière connexion',
    'balance' => 'Solde',
    'action' => 'Action',
    'status' => 'Statut',
    'invoice_total' => 'Montant total',
    'frequency' => 'Fréquence',
    'range' => 'Portée',
    'start_date' => 'Date de début',
    'end_date' => 'Date de fin',
    'transaction_reference' => 'Référence transaction',
    'method' => 'Méthode',
    'payment_amount' => 'Montant du paiement',
    'payment_date' => 'Date du paiement',
    'credit_amount' => 'Montant du crédit',
    'credit_balance' => 'Solde du crédit',
    'credit_date' => 'Date d\'avoir',
    'empty_table' => 'Aucune donnée disponible dans la table',
    'select' => 'Sélectionner',
    'edit_client' => 'Modifier ce client',
    'edit_invoice' => 'Modifier la facture',
    'create_invoice' => 'Créer une facture',
    'enter_credit' => 'Saisissez un crédit',
    'last_logged_in' => 'Dernière connexion',
    'details' => 'Détails',
    'standing' => 'En attente',
    'credit' => 'Crédit',
    'activity' => 'Activité',
    'date' => 'Date',
    'message' => 'Message',
    'adjustment' => 'Réglements',
    'are_you_sure' => 'Voulez-vous vraiment effectuer cette action ?',
    'payment_type_id' => 'Type de paiement',
    'amount' => 'Montant',
    'work_email' => 'Courriel',
    'language_id' => 'Langue',
    'timezone_id' => 'Fuseau horaire',
    'date_format_id' => 'Format de la date',
    'datetime_format_id' => 'Format Date/Heure',
    'users' => 'Utilisateurs',
    'localization' => 'Localisation',
    'remove_logo' => 'Supprimer le logo',
    'logo_help' => 'Formats supportés : JPEG, GIF et PNG',
    'payment_gateway' => 'Passerelle de paiement',
    'gateway_id' => 'Fournisseur',
    'email_notifications' => 'Notifications par courriel',
    'email_sent' => 'M\'envoyer un courriel quand une facture est <b>envoyée</b>',
    'email_viewed' => 'M\'envoyer un courriel quand une facture est <b>vue</b>',
    'email_paid' => 'M\'envoyer un courriel quand une facture est <b>payée</b>',
    'site_updates' => 'Mises à jour du site',
    'custom_messages' => 'Messages personnalisés',
    'default_email_footer' => 'Définir comme <b>la signature de courriel</b> par défaut',
    'select_file' => 'Veuillez sélectionner un fichier',
    'first_row_headers' => 'Utiliser la première ligne comme en-tête',
    'column' => 'Colonne',
    'sample' => 'Exemple',
    'import_to' => 'Importer en tant que',
    'client_will_create' => 'client sera créé',
    'clients_will_create' => 'clients seront créés',
    'email_settings' => 'Paramètres de courriel',
    'client_view_styling' => 'Style de la vue client',
    'pdf_email_attachment' => 'Joindre PDF',
    'custom_css' => 'CSS personnalisé',
    'import_clients' => 'Importer des données clients',
    'csv_file' => 'Sélectionner un fichier CSV',
    'export_clients' => 'Exporter des données clients',
    'created_client' => 'Client créé avec succès',
    'created_clients' => ':count client(s) créé(s) avec succès',
    'updated_settings' => 'Paramètres mis à jour avec succès',
    'removed_logo' => 'Logo supprimé avec succès',
    'sent_message' => 'Message envoyé avec succès',
    'invoice_error' => 'Veuillez vous assurer de sélectionner un client et de corriger les erreurs',
    'limit_clients' => 'Désolé, cela dépasse la limite de :count clients',
    'payment_error' => 'Il y a eu une erreur lors du traitement de votre paiement. Veuillez réessayer ultérieurement',
    'registration_required' => 'Veuillez vous enregistrer pour envoyer une facture par courriel',
    'confirmation_required' => 'Veuillez confirmer votre adresse courriel, :link pour renvoyer le courriel de confirmation.',
    'updated_client' => 'Client modifié avec succès',
    'archived_client' => 'Client archivé avec succès',
    'archived_clients' => ':count clients archivés avec succès',
    'deleted_client' => 'Client supprimé avec succès',
    'deleted_clients' => ':count clients supprimés avec succès',
    'updated_invoice' => 'Facture modifiée avec succès',
    'created_invoice' => 'Facture créée avec succès',
    'cloned_invoice' => 'Facture dupliquée avec succès',
    'emailed_invoice' => 'Facture envoyée par courriel avec succès',
    'and_created_client' => 'et client créé',
    'archived_invoice' => 'Facture archivée avec succès',
    'archived_invoices' => ':count factures archivées avec succès',
    'deleted_invoice' => 'Facture supprimée avec succès',
    'deleted_invoices' => ':count factures supprimées avec succès',
    'created_payment' => 'Paiement créé avec succès',
    'created_payments' => ':count paiement(s) créé(s)',
    'archived_payment' => 'Paiement archivé avec succès',
    'archived_payments' => ':count paiement archivés avec succès',
    'deleted_payment' => 'Paiement supprimé avec succès',
    'deleted_payments' => ':count paiements supprimés avec succès',
    'applied_payment' => 'Paiement enregistré avec succès',
    'created_credit' => 'Crédit créé avec succès',
    'archived_credit' => 'Crédit archivé avec succès',
    'archived_credits' => ':count crédits archivés avec succès',
    'deleted_credit' => 'Crédit supprimé avec succès',
    'deleted_credits' => ':count crédits supprimés avec succès',
    'imported_file' => 'Fichier importé avec succès',
    'updated_vendor' => 'Founisseur mis à jour avec succès',
    'created_vendor' => 'Fournisseur créé avec succès',
    'archived_vendor' => 'Fournisseur archivé avec succès',
    'archived_vendors' => ':count fournisseurs archivés avec succès',
    'deleted_vendor' => 'Fournisseur supprimé avec succès',
    'deleted_vendors' => ':count fournisseurs supprimés avec succès',
    'confirmation_subject' => 'Validation du compte Invoice Ninja',
    'confirmation_header' => 'Validation du compte',
    'confirmation_message' => 'Veuillez cliquer sur le lien ci-après pour valider votre compte.',
    'invoice_subject' => 'Nouvelle facture :number de :account',
    'invoice_message' => 'Pour visionner votre facture de :amount, cliquez sur le lien ci-dessous.',
    'payment_subject' => 'Paiement reçu',
    'payment_message' => 'Merci pour votre paiement d’un montant de :amount',
    'email_salutation' => 'Cher :name,',
    'email_signature' => 'Cordialement,',
    'email_from' => 'L’équipe Invoice Ninja',
    'invoice_link_message' => 'Pour voir la facture de votre client cliquez sur le lien ci-dessous :',
    'notification_invoice_paid_subject' => 'La facture :invoice a été payée par le client :client',
    'notification_invoice_sent_subject' => 'La facture :invoice a été envoyée au client :client',
    'notification_invoice_viewed_subject' => 'La facture :invoice a été vue par le client :client',
    'notification_invoice_paid' => 'Un paiement de :amount a été effectué par le client :client concernant la facture :invoice.',
    'notification_invoice_sent' => 'Le client :client a reçu par courriel la facture :invoice d\'un montant de :amount',
    'notification_invoice_viewed' => 'Le client :client a vu la facture :invoice d\'un montant de :amount',
    'reset_password' => 'Vous pouvez réinitialiser votre mot de passe en cliquant sur le lien suivant :',
    'secure_payment' => 'Paiement sécurisé',
    'card_number' => 'Numéro de carte',
    'expiration_month' => 'Mois d\'expiration',
    'expiration_year' => 'Année d\'expiration',
    'cvv' => 'Cryptogramme visuel',
    'logout' => 'Se déconnecter',
    'sign_up_to_save' => 'Connectez-vous pour sauvegarder votre travail',
    'agree_to_terms' => 'J\'accepte les :terms',
    'terms_of_service' => 'Conditions d\'utilisation',
    'email_taken' => 'L\'adresse courriel existe déjà',
    'working' => 'En cours',
    'success' => 'Succès',
    'success_message' => 'Inscription réussie. Veuillez cliquer sur le lien dans le courriel de confirmation de compte pour vérifier votre adresse courriel.',
    'erase_data' => 'Votre compte n\'est pas enregistré, cela va supprimer définitivement vos données',
    'password' => 'Mot de passe',
    'pro_plan_product' => 'Plan Pro',
    'pro_plan_success' => 'Merci pour votre inscription ! Une fois la facture réglée, votre adhésion au Plan Pro commencera.',
    'unsaved_changes' => 'Vous avez des modifications non enregistrées',
    'custom_fields' => 'Champs personnalisés',
    'company_fields' => 'Champs de société',
    'client_fields' => 'Champs client',
    'field_label' => 'Nom du champ',
    'field_value' => 'Valeur du champ',
    'edit' => 'Éditer',
    'set_name' => 'Saisir le nom de votre entreprise',
    'view_as_recipient' => 'Voir en tant que destinataire',
    'product_library' => 'Inventaire',
    'product' => 'Produit',
    'products' => 'Produits',
    'fill_products' => 'Remplissage auto des produits',
    'fill_products_help' => 'La sélection d’un produit entrainera la MAJ de <b>la description et du prix</b>',
    'update_products' => 'Mise à jour auto des produits',
    'update_products_help' => 'La mise à jour d\'une facture entraîne la <b>mise à jour des produits</b>',
    'create_product' => 'Nouveau produit',
    'edit_product' => 'Éditer ce produit',
    'archive_product' => 'Archiver ce produit',
    'updated_product' => 'Produit mis à jour avec succès',
    'created_product' => 'Produit créé avec succès',
    'archived_product' => 'Produit archivé avec succès',
    'pro_plan_custom_fields' => ':link pour activer les champs personnalisés en rejoignant le Plan Pro',
    'advanced_settings' => 'Paramètres avancés',
    'pro_plan_advanced_settings' => ':link pour activer les paramètres avancés en rejoignant le Plan Pro',
    'invoice_design' => 'Modèle de facture',
    'specify_colors' => 'Spécifiez les couleurs',
    'specify_colors_label' => 'Sélectionnez les couleurs utilisées dans les factures',
    'chart_builder' => 'Concepteur de graphiques',
    'ninja_email_footer' => 'Créé par :site | Créez. Envoyez. Encaissez.',
    'go_pro' => 'Passez au Plan Pro',
    'quote' => 'Devis',
    'quotes' => 'Devis',
    'quote_number' => 'Devis numéro',
    'quote_number_short' => 'Devis #',
    'quote_date' => 'Date du devis',
    'quote_total' => 'Montant du devis',
    'your_quote' => 'Votre devis',
    'total' => 'Total',
    'clone' => 'Dupliquer',
    'new_quote' => 'Nouveau devis',
    'create_quote' => 'Créer un devis',
    'edit_quote' => 'Éditer ce devis',
    'archive_quote' => 'Archiver ce devis',
    'delete_quote' => 'Supprimer ce devis',
    'save_quote' => 'Enregistrer ce devis',
    'email_quote' => 'Envoyer ce devis par courriel',
    'clone_quote' => 'Dupliquer en devis',
    'convert_to_invoice' => 'Convertir en facture',
    'view_invoice' => 'Voir la facture',
    'view_client' => 'Voir le client',
    'view_quote' => 'Voir le devis',
    'updated_quote' => 'Devis mis à jour avec succès',
    'created_quote' => 'Devis créé avec succès',
    'cloned_quote' => 'Devis dupliqué avec succès',
    'emailed_quote' => 'Devis envoyé par courriel avec succès',
    'archived_quote' => 'Devis archivé avec succès',
    'archived_quotes' => ':count devis archivés avec succès',
    'deleted_quote' => 'Devis supprimé avec succès',
    'deleted_quotes' => ':count devis supprimés avec succès',
    'converted_to_invoice' => 'Devis converti en facture avec succès',
    'quote_subject' => 'Nouveau devis :number de :account',
    'quote_message' => 'Pour visionner votre devis de :amount, cliquez sur le lien ci-dessous.',
    'quote_link_message' => 'Pour visionner votre devis, cliquez sur le lien ci-dessous :',
    'notification_quote_sent_subject' => 'Le devis :invoice a été envoyé à :client',
    'notification_quote_viewed_subject' => 'Le devis :invoice a été visionné par :client',
    'notification_quote_sent' => 'Le devis :invoice de :amount a été mailé au client :client.',
    'notification_quote_viewed' => 'Le devis :invoice de :amount a été visionné par le client :client.',
    'session_expired' => 'Votre session a expiré.',
    'invoice_fields' => 'Champs de facture',
    'invoice_options' => 'Options de facturation',
    'hide_paid_to_date' => 'Masquer "Payé à ce jour"',
    'hide_paid_to_date_help' => 'Afficher la ligne "Payé à ce jour" sur vos factures seulement une fois qu\'un paiement a été reçu.',
    'charge_taxes' => 'Taxe supplémentaire',
    'user_management' => 'Gestion des utilisateurs',
    'add_user' => 'Ajouter un utilisateur',
    'send_invite' => 'Envoyer une invitation',
    'sent_invite' => 'Invitation envoyée avec succès',
    'updated_user' => 'Utilisateur mis à jour avec succès',
    'invitation_message' => 'Vous avez été invité(e) par :invitor. ',
    'register_to_add_user' => 'Veuillez vous enregistrer pour ajouter un utilisateur',
    'user_state' => 'Province/Département',
    'edit_user' => 'Éditer l\'utilisateur',
    'delete_user' => 'Supprimer l\'utilisateur',
    'active' => 'Actif',
    'pending' => 'En attente',
    'deleted_user' => 'Utilisateur supprimé avec succès',
    'confirm_email_invoice' => 'Voulez-vous vraiment envoyer cette facture par courriel ?',
    'confirm_email_quote' => 'Voulez-vous vraiment envoyer ce devis par courriel ?',
    'confirm_recurring_email_invoice' => 'Les factures récurrentes sont activées, voulez-vous vraiment mailer cette facture ?',
    'confirm_recurring_email_invoice_not_sent' => 'Etes-vous sûr(e) de vouloir commencer la récurrence ?',
    'cancel_account' => 'Supprimer le compte',
    'cancel_account_message' => 'Attention : Ceci va supprimer définitivement votre compte, il n\'y a pas d\'annulation possible.',
    'go_back' => 'Retour',
    'data_visualizations' => 'Visualisation des données',
    'sample_data' => 'Données fictives présentées',
    'hide' => 'Cacher',
    'new_version_available' => 'Une nouvelle version de :releases_link est disponible. Vous utilisez v:user_version, la plus récente est v:latest_version',
    'invoice_settings' => 'Paramètres des factures',
    'invoice_number_prefix' => 'Préfixe du numéro de facture',
    'invoice_number_counter' => 'Compteur du numéro de facture',
    'quote_number_prefix' => 'Préfixe du numéro de devis',
    'quote_number_counter' => 'Compteur du numéro de devis',
    'share_invoice_counter' => 'Partager le compteur de facture',
    'invoice_issued_to' => 'Facture destinée à',
    'invalid_counter' => 'Pour éviter un éventuel conflit, merci de définir un préfixe pour le numéro de facture ou pour le numéro de devis',
    'mark_sent' => 'Marquer comme envoyé',
    'gateway_help_1' => ':link pour vous inscrire à Authorize.net.',
    'gateway_help_2' => ':link pour vous inscrire à Authorize.net.',
    'gateway_help_17' => ':link pour obtenir votre signature PayPal API.',
    'gateway_help_27' => ':link pour vous inscrire à 2Checkout.com. Pour permettre le suivi des paiements, veuillez définir :complete_link comme URL de redirection dans Mon compte > Gestion de site dans le portail de 2Checkout.',
    'gateway_help_60' => ':link pour créer un compte WePay.',
    'more_designs' => 'Plus de modèles',
    'more_designs_title' => 'Modèles de factures additionnels',
    'more_designs_cloud_header' => 'Passez au Plan Pro pour plus de modèles',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Acheter',
    'bought_designs' => 'Les nouveaux modèles ont été ajoutés avec succès',
    'sent' => 'Envoyé',
    'vat_number' => 'Numéro de TVA',
    'timesheets' => 'Feuilles de temps',
    'payment_title' => 'Entrez votre adresse de facturation et vos informations bancaires',
    'payment_cvv' => '*Ce sont les 3-4 numéros à l\'arrière de votre carte',
    'payment_footer1' => '*L’adresse de facturation doit correspondre à celle enregistrée avec votre carte bancaire',
    'payment_footer2' => '*Merci de cliquer sur "Payer maintenant" une seule fois. Le processus peut prendre jusqu\'à 1 minute.',
    'id_number' => 'Numéro ID',
    'white_label_link' => 'Marque blanche',
    'white_label_header' => 'Marque blanche',
    'bought_white_label' => 'Licence marque blanche activée avec succès',
    'white_labeled' => 'Marque blanche',
    'restore' => 'Restaurer',
    'restore_invoice' => 'Restaurer la facture',
    'restore_quote' => 'Restaurer le devis',
    'restore_client' => 'Restaurer le client',
    'restore_credit' => 'Restaurer le crédit',
    'restore_payment' => 'Restaurer le paiement',
    'restored_invoice' => 'Facture restaurée avec succès',
    'restored_quote' => 'Devis restauré avec succès',
    'restored_client' => 'Client restauré avec succès',
    'restored_payment' => 'Paiement restauré avec succès',
    'restored_credit' => 'Crédit restauré avec succès',
    'reason_for_canceling' => 'Aidez-nous à améliorer notre site en nous disant pourquoi vous partez.',
    'discount_percent' => 'Pourcent',
    'discount_amount' => 'Montant',
    'invoice_history' => 'Historique des factures',
    'quote_history' => 'Historique des devis',
    'current_version' => 'Version actuelle',
    'select_version' => 'Choix de la version',
    'view_history' => 'Consulter l\'historique',
    'edit_payment' => 'Éditer le paiement',
    'updated_payment' => 'Paiement mis à jour avec succès',
    'deleted' => 'Supprimé',
    'restore_user' => 'Restaurer l’utilisateur',
    'restored_user' => 'Commande restaurée avec succès',
    'show_deleted_users' => 'Voir les utilisateurs supprimés',
    'email_templates' => 'Modèles de courriel',
    'invoice_email' => 'Courriel de facture',
    'payment_email' => 'Courriel de paiement',
    'quote_email' => 'Courriel de devis',
    'reset_all' => 'Réinitialiser tout',
    'approve' => 'Accepter',
    'token_billing_type_id' => 'Jeton de paiement',
    'token_billing_help' => 'Stocker les détails de paiement avec WePay, Stripe, Braintree ou GoCardless.',
    'token_billing_1' => 'Désactiver',
    'token_billing_2' => 'Opt-in - Case à cocher affichée mais non sélectionnée',
    'token_billing_3' => 'Opt-out - Case à cocher affichée et sélectionnée',
    'token_billing_4' => 'Toujours',
    'token_billing_checkbox' => 'Enregistrer les informations de paiement',
    'view_in_gateway' => 'Voir sur :gateway',
    'use_card_on_file' => 'Utiliser la carte bancaire enregistrée',
    'edit_payment_details' => 'Modifier les détails de paiement',
    'token_billing' => 'Enregister les détails de paiement',
    'token_billing_secure' => 'Les données sont enregistrées de manière sécurisée par :link',
    'support' => 'Support',
    'contact_information' => 'Informations de contact',
    '256_encryption' => 'Cryptage 256 bit',
    'amount_due' => 'Montant dû',
    'billing_address' => 'Adresse de facturation',
    'billing_method' => 'Méthode de facturation',
    'order_overview' => 'Résumé de la commande',
    'match_address' => '*L\'adresse doit correspondre à l\'adresse associée à la carte de crédit.',
    'click_once' => '*Merci de cliquer sur "Payer maintenant" une seule fois. Le processus peut prendre jusqu\'à 1 minute.',
    'invoice_footer' => 'Pied de facture',
    'save_as_default_footer' => 'Définir comme pied de facture par défaut',
    'token_management' => 'Gestion des jetons',
    'tokens' => 'Jetons',
    'add_token' => 'Ajouter un jeton',
    'show_deleted_tokens' => 'Voir les jetons supprimés',
    'deleted_token' => 'Jeton supprimé avec succès',
    'created_token' => 'Jeton créé avec succès',
    'updated_token' => 'Jeton mis à jour avec succès',
    'edit_token' => 'Éditer ce jeton',
    'delete_token' => 'Supprimer ce jeton',
    'token' => 'Jeton',
    'add_gateway' => 'Ajouter une passerelle',
    'delete_gateway' => 'Supprimer la passerelle',
    'edit_gateway' => 'Éditer la passerelle',
    'updated_gateway' => 'Passerelle mise à jour avec succès',
    'created_gateway' => 'Passerelle créée avec succès',
    'deleted_gateway' => 'Passerelle supprimée avec succès',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Carte bancaire',
    'change_password' => 'Changer le mot de passe',
    'current_password' => 'Mot de passe actuel',
    'new_password' => 'Nouveau mot de passe',
    'confirm_password' => 'Confirmer le mot de passe',
    'password_error_incorrect' => 'Le mot de passe actuel est incorrect.',
    'password_error_invalid' => 'Le nouveau mot de passe est invalide.',
    'updated_password' => 'Mot de passe mis à jour avec succès',
    'api_tokens' => 'Jetons d\'API',
    'users_and_tokens' => 'Utilisateurs & jetons',
    'account_login' => 'Connexion à votre compte',
    'recover_password' => 'Récupérer votre mot de passe',
    'forgot_password' => 'Mot de passe oublié ?',
    'email_address' => 'Adresse courriel',
    'lets_go' => 'Allons-y !',
    'password_recovery' => 'Récupération du mot de passe',
    'send_email' => 'Envoyer courriel',
    'set_password' => 'Définir le mot de passe',
    'converted' => 'Converti',
    'email_approved' => 'M\'envoyer un courriel quand un devis est <b>approuvé</b>',
    'notification_quote_approved_subject' => 'Le devis :invoice a été approuvé par :client',
    'notification_quote_approved' => 'Le client :client a approuvé le devis :invoice pour un montant de :amount.',
    'resend_confirmation' => 'Renvoyer le courriel de confirmation',
    'confirmation_resent' => 'Le courriel de confirmation a été renvoyé',
    'gateway_help_42' => ':link pour vous inscrire à BitPay <br/> Remarque:. utiliser une clé API "Legacy", pas un jeton.',
    'payment_type_credit_card' => 'Carte de crédit',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Base de connaissances',
    'partial' => 'Partiel/dépôt',
    'partial_remaining' => ':partial de :balance',
    'more_fields' => 'Plus de champs',
    'less_fields' => 'Moins de champs',
    'client_name' => 'Nom du client',
    'pdf_settings' => 'Réglages PDF',
    'product_settings' => 'Réglages du produit',
    'auto_wrap' => 'Retour à la ligne automatique',
    'duplicate_post' => 'Attention: la page précédente a été soumise deux fois. La deuxième soumission a été ignorée.',
    'view_documentation' => 'Voir documentation',
    'app_title' => 'Outil de facturation gratuit & Open-Source',
    'app_description' => 'Invoice Ninja est une application gratuite et libre (open-source) pour faire des devis et facturer ses clients. Avec Invoice Ninja, vous pouvez facilement créer et envoyer de magnifiques factures depuis n’importe quel terminal possédant un accès à Internet. Vos clients peuvent imprimer vos factures, les télécharger en tant que fichiers pdf, et même vous payer en ligne via l\'application.',
    'rows' => 'lignes',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Sous-domaine',
    'provide_name_or_email' => 'Veuillez indiquer un nom ou un courriel',
    'charts_and_reports' => 'Graphiques & rapports',
    'chart' => 'Graphique',
    'report' => 'Rapport',
    'group_by' => 'Grouper par',
    'paid' => 'Payé',
    'enable_report' => 'Rapport',
    'enable_chart' => 'Graphiques',
    'totals' => 'Totaux',
    'run' => 'Lancer',
    'export' => 'Exporter',
    'documentation' => 'Documentation',
    'zapier' => 'Zapier',
    'recurring' => 'Récurrent',
    'last_invoice_sent' => 'Dernière facture envoyée le :date',
    'processed_updates' => 'Mise à jour effectuée avec succès',
    'tasks' => 'Tâches',
    'new_task' => 'Nouvelle tâche',
    'start_time' => 'Début',
    'created_task' => 'Tâche créée avec succès',
    'updated_task' => 'Tâche mise à jour avec succès',
    'edit_task' => 'Éditer la tâche',
    'clone_task' => 'Dupliquer la tâche',
    'archive_task' => 'Archiver la tâche',
    'restore_task' => 'Restaurer la tâche',
    'delete_task' => 'Supprimer la tâche',
    'stop_task' => 'Arrêter la tâche',
    'time' => 'Temps',
    'start' => 'Début',
    'stop' => 'Fin',
    'now' => 'Maintenant',
    'timer' => 'Compteur',
    'manual' => 'Manuel',
    'date_and_time' => 'Date & heure',
    'second' => 'Seconde',
    'seconds' => 'Secondes',
    'minute' => 'Minute',
    'minutes' => 'Minutes',
    'hour' => 'Heure',
    'hours' => 'Heures',
    'task_details' => 'Détails de la tâche',
    'duration' => 'Durée',
    'time_log' => 'Journal de temps',
    'end_time' => 'Heure de fin',
    'end' => 'Fin',
    'invoiced' => 'Facturé',
    'logged' => 'Enregistré',
    'running' => 'En cours',
    'task_error_multiple_clients' => 'Les tâches ne peuvent pas appartenir à différents clients',
    'task_error_running' => 'Merci de tout d\'abord arrêter les tâches en cours',
    'task_error_invoiced' => 'Tâches déjà facturées',
    'restored_task' => 'Tâche restaurée avec succès',
    'archived_task' => 'Tâche archivée avec succès',
    'archived_tasks' => ':count tâches archivées avec succès',
    'deleted_task' => 'Tâche supprimée avec succès',
    'deleted_tasks' => ':count tâches supprimées avec succès',
    'create_task' => 'Créer une tâche',
    'stopped_task' => 'Tâche stoppée avec succès',
    'invoice_task' => 'Facturer la tâche',
    'invoice_labels' => 'Libellés facture',
    'prefix' => 'Préfixe',
    'counter' => 'Compteur',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link pour vous inscrire à Dwolla.',
    'partial_value' => 'Doit être supérieur à zéro et inférieur au total',
    'more_actions' => 'Plus d\'actions',
    'pro_plan_title' => 'Plan NINJA PRO',
    'pro_plan_call_to_action' => 'Mettre à jour maintenant !',
    'pro_plan_feature1' => 'Créer un nombre illimité de clients',
    'pro_plan_feature2' => 'Accéder à 10 magnifiques designs de factures',
    'pro_plan_feature3' => 'URLs personnalisées - "VotreMarque.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Retirer "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Accès multi-utilisateur & suivi de l\'activité',
    'pro_plan_feature6' => 'Créer des Devis & Pro-forma',
    'pro_plan_feature7' => 'Personnaliser les champs Titre et Numérotation des factures',
    'pro_plan_feature8' => 'Option pour attacher des PDFs aux courriels pour le client',
    'resume' => 'Reprendre',
    'break_duration' => 'Pause',
    'edit_details' => 'Modifier',
    'work' => 'Travail',
    'timezone_unset' => 'Merci de :link pour définir votre fuseau horaire',
    'click_here' => 'cliquer ici',
    'email_receipt' => 'Envoyer le reçu par courriel au client',
    'created_payment_emailed_client' => 'Paiement créé avec succès et envoyé par courriel au client',
    'add_company' => 'Ajouter compte',
    'untitled' => 'Sans titre',
    'new_company' => 'Nouveau compte',
    'associated_accounts' => 'Comptes liés avec succès',
    'unlinked_account' => 'Comptes dissociés avec succès',
    'login' => 'Connexion',
    'or' => 'ou',
    'email_error' => 'Il y a eu un problème en envoyant le courriel',
    'confirm_recurring_timing' => 'Note : les courriels sont envoyés au début de l\'heure.',
    'confirm_recurring_timing_not_sent' => 'Note : les factures sont créées au début de l\'heure.',
    'payment_terms_help' => 'Définit <b>la date d\'échéance de la facture</b> par défaut ',
    'unlink_account' => 'Dissocier le compte',
    'unlink' => 'Dissocier',
    'show_address' => 'Montrer l\'adresse',
    'show_address_help' => 'Éxiger du client qu\'il fournisse une adresse de facturation',
    'update_address' => 'Mettre à jour l\'adresse',
    'update_address_help' => 'Mettre à jour l\'adresse du client avec les détails fournis',
    'times' => 'Horaires',
    'set_now' => 'Définir maintenant',
    'dark_mode' => 'Mode sombre',
    'dark_mode_help' => 'Fond sombre pour les barres latérale',
    'add_to_invoice' => 'Ajouter à la facture :invoice',
    'create_new_invoice' => 'Créer une nouvelle facture',
    'task_errors' => 'Merci de corriger les horaires conflictuels',
    'from' => 'De',
    'to' => 'À',
    'font_size' => 'Taille de police',
    'primary_color' => 'Couleur principale',
    'secondary_color' => 'Couleur secondaire',
    'customize_design' => 'Design personnalisé',
    'content' => 'Contenu',
    'styles' => 'Styles',
    'defaults' => 'Valeurs par défaut',
    'margins' => 'Marges',
    'header' => 'En-tête',
    'footer' => 'Pied de page',
    'custom' => 'Personnalisé',
    'invoice_to' => 'Facture pour',
    'invoice_no' => 'Facture n°',
    'quote_no' => 'Devis n°',
    'recent_payments' => 'Paiements récents',
    'outstanding' => 'Impayé',
    'manage_companies' => 'Gérer les sociétés',
    'total_revenue' => 'Revenu total',
    'current_user' => 'Utilisateur actuel',
    'new_recurring_invoice' => 'Nouvelle facture récurrente',
    'recurring_invoice' => 'Facture récurrente',
    'new_recurring_quote' => 'Créer un devis regulier',
    'recurring_quote' => 'Devis récurrent',
    'recurring_too_soon' => 'Il est trop tôt pour créer la prochaine facture récurrente, prévue pour le :date',
    'created_by_invoice' => 'Créé par :invoice',
    'primary_user' => 'Utilisateur principal',
    'help' => 'Aide',
    'customize_help' => '<p>Nous utilisons :pdfmake_link pour définir les styles de facture de manière déclarative. La :playground_link pdfmake fournit une excellente façon de voir la bibliothèque en action.</p>
                        <p>Si vous avez besoin d\'aide pour trouver quelque chose, postez une question sur notre :forum_link avec le design que vous utilisez.</p>',
    'playground' => 'cour de récréation',
    'support_forum' => 'forum de support',
    'invoice_due_date' => 'Date limite',
    'quote_due_date' => 'Date limite',
    'valid_until' => 'Valide jusqu\'au',
    'reset_terms' => 'Ràz conditions',
    'reset_footer' => 'Ràz pied de facture',
    'invoice_sent' => ':count facture envoyée',
    'invoices_sent' => ':count factures envoyées',
    'status_draft' => 'Brouillon',
    'status_sent' => 'Envoyé',
    'status_viewed' => 'Vu',
    'status_partial' => 'Partiel',
    'status_paid' => 'Payé',
    'status_unpaid' => 'Non payé',
    'status_all' => 'Tout',
    'show_line_item_tax' => 'Afficher <b>les taxes de l\'article de la ligne</b> pour chaque ligne',
    'iframe_url' => 'Site internet',
    'iframe_url_help1' => 'Copiez le code suivant sur une page de votre site.',
    'iframe_url_help2' => 'Vous pouvez tester la fonctionnalité en cliquant sur \'Voir en tant que destinataire\' pour une facture.',
    'auto_bill' => 'Facturation automatique',
    'military_time' => '24H',
    'last_sent' => 'Dernier envoi',
    'reminder_emails' => 'Courriel de rappel',
    'quote_reminder_emails' => 'Citer les emails de relance',
    'templates_and_reminders' => 'Modèles & Rappels',
    'subject' => 'Sujet',
    'body' => 'Corps',
    'first_reminder' => 'Premier rappel',
    'second_reminder' => 'Second rappel',
    'third_reminder' => 'Troisième rappel',
    'num_days_reminder' => 'Jours après la date d\'échéance',
    'reminder_subject' => 'Rappel : Facture :invoice de :account',
    'reset' => 'Remettre à zéro',
    'invoice_not_found' => 'La facture demandée n\'est pas disponible',
    'referral_program' => 'Programme de parrainage',
    'referral_code' => 'Code de Parrainage',
    'last_sent_on' => 'Dernier envoi le :date',
    'page_expire' => 'Cette page va bientôt expirer, :click_here pour continuer à travailler',
    'upcoming_quotes' => 'Devis à venir',
    'expired_quotes' => 'Devis expirés',
    'sign_up_using' => 'Connexion avec',
    'invalid_credentials' => 'Ces informations de connexion sont invalides',
    'show_all_options' => 'Voir toutes les options',
    'user_details' => 'Utilisateur',
    'oneclick_login' => 'Comptes connectés',
    'disable' => 'Désactiver',
    'invoice_quote_number' => 'Numéro des devis & factures',
    'invoice_charges' => 'Majoration de facture',
    'notification_invoice_bounced' => 'Impossible d\'envoyer la facture :invoice à :contact.',
    'notification_invoice_bounced_subject' => 'Impossible d\'envoyer la facture :invoice',
    'notification_quote_bounced' => 'Impossible d\'envoyer le devis :invoice à :contact.',
    'notification_quote_bounced_subject' => 'Impossible d\'envoyer le devis :invoice',
    'custom_invoice_link' => 'Personnaliser le lien de la facture',
    'total_invoiced' => 'Total facturé',
    'open_balance' => 'Solde',
    'verify_email' => 'Cliquez sur le lien dans le courriel de confirmation de compte pour valider votre adresse e-Mail.',
    'basic_settings' => 'Paramètres de base',
    'pro' => 'Pro',
    'gateways' => 'Passerelles de paiement',
    'next_send_on' => 'Envoi suivant : :date',
    'no_longer_running' => 'La facturation n\'est pas planifiée pour être lancée',
    'general_settings' => 'Paramètres généraux',
    'customize' => 'Personnaliser',
    'oneclick_login_help' => 'Connectez un compte pour vous connecter sans votre mot de passe',
    'referral_code_help' => 'Gagnez de l\'argent en partageant notre outil en ligne',
    'enable_with_stripe' => 'Activer | Stripe est requis',
    'tax_settings' => 'Réglages des taxes',
    'create_tax_rate' => 'Ajouter un taux de taxe.',
    'updated_tax_rate' => 'Taux de taxe mis à jour avec succès',
    'created_tax_rate' => 'Taux de taxe créé avec succès',
    'edit_tax_rate' => 'Éditer le taux de taxe',
    'archive_tax_rate' => 'Archiver le taux de taxe',
    'archived_tax_rate' => 'Taux de taxe archivé avec succès',
    'default_tax_rate_id' => 'Taux de taxe par défaut',
    'tax_rate' => 'Taux de taxe',
    'recurring_hour' => 'Heure récurrente',
    'pattern' => 'Pattern',
    'pattern_help_title' => 'Aide Pattern',
    'pattern_help_1' => 'Créer un numéro personnalisé en précisant un modèle personnalisé',
    'pattern_help_2' => 'Variables disponibles :',
    'pattern_help_3' => 'Par exemple, :example sera converti en :value',
    'see_options' => 'Voir les options',
    'invoice_counter' => 'Compteur de factures',
    'quote_counter' => 'Compteur de devis',
    'type' => 'Type',
    'activity_1' => ':user a créé le client :client',
    'activity_2' => ':user a archivé le client :client',
    'activity_3' => ':user a supprimé le client :client',
    'activity_4' => ':user a créé la facture :invoice',
    'activity_5' => ':user a mis à jour la facture :invoice',
    'activity_6' => ':user a mailé la facture :invoice pour :client à :contact',
    'activity_7' => ':contact a vu la facture :invoice pour :client',
    'activity_8' => ':user a archivé la facture :invoice',
    'activity_9' => ':user a supprimé la facture :invoice',
    'activity_10' => ':contact a saisi un paiement :payment concernant :invoice pour :client',
    'activity_11' => ':user a mis à jour le moyen de paiement :payment',
    'activity_12' => ':user a archivé le moyen de paiement :payment',
    'activity_13' => ':user a supprimé le moyen de paiement :payment',
    'activity_14' => ':user a entré le crédit :credit',
    'activity_15' => ':user a mis à jour le crédit :credit',
    'activity_16' => ':user a archivé le crédit :credit',
    'activity_17' => ':user a supprimé le crédit :credit',
    'activity_18' => ':user a créé le devis :quote',
    'activity_19' => ':user a mis à jour le devis :quote',
    'activity_20' => ':user a mailé un devis :quote pour :client à :contact',
    'activity_21' => ':contact a lu le devis :quote',
    'activity_22' => ':user a archivé le devis :quote',
    'activity_23' => ':user a supprimé le devis :quote',
    'activity_24' => ':user a restauré le devis :quote',
    'activity_25' => ':user a restauré la facture :invoice',
    'activity_26' => ':user a restauré le client :client',
    'activity_27' => ':user a restauré le paiement :payment',
    'activity_28' => ':user a restauré le crédit :credit',
    'activity_29' => ':contact a approuvé le devis :quote pour :client',
    'activity_30' => ':user a créé le fournisseur :vendor',
    'activity_31' => ':user a archivé le fournisseur :vendor',
    'activity_32' => ':user a supprimé le fournisseur :vendor',
    'activity_33' => ':user a restauré le fournisseur :vendor',
    'activity_34' => ':user a créé la dépense :expense',
    'activity_35' => ':user a archivé la dépense :expense',
    'activity_36' => ':user a supprimé la dépense :expense',
    'activity_37' => ':user a restauré la dépense :expense',
    'activity_42' => ':user a créé la tâche :task',
    'activity_43' => ':user a mis à jour la tâche :task',
    'activity_44' => ':user a archivé la tâche :task',
    'activity_45' => ':user a supprimé la tâche :task',
    'activity_46' => ':user a restauré la tâche :task',
    'activity_47' => ':user a mis à jour la dépense :expense',
    'activity_48' => ':user a mis à jour le ticket :ticket',
    'activity_49' => ':user a fermé le ticket :ticket',
    'activity_50' => ':user a fusionner le ticket :ticket',
    'activity_51' => ':user a divisé le :ticket',
    'activity_52' => ':contact a ouvert le ticket :ticket',
    'activity_53' => ':contact a ré-ouvert le ticket :ticket',
    'activity_54' => ':user a ré-ouvert le ticket :ticket',
    'activity_55' => ':contact a répondu au ticket :ticket',
    'activity_56' => ':user a visualisé le ticket :ticket',

    'payment' => 'Paiement',
    'system' => 'Système',
    'signature' => 'Signature du courriel',
    'default_messages' => 'Messages par défaut',
    'quote_terms' => 'Conditions des devis',
    'default_quote_terms' => 'Conditions des devis par défaut',
    'default_invoice_terms' => 'Définir comme conditions de facturation par défaut',
    'default_invoice_footer' => 'Définir par défaut',
    'quote_footer' => 'Pied de page des devis',
    'free' => 'Gratuit',
    'quote_is_approved' => 'Approuvé avec succès',
    'apply_credit' => 'Appliquer crédit',
    'system_settings' => 'Paramètres système',
    'archive_token' => 'Archiver jeton',
    'archived_token' => 'Jeton archivé avec succès',
    'archive_user' => 'Archiver utilisateur',
    'archived_user' => 'Utilisateur archivé avec succès',
    'archive_account_gateway' => 'Supprimer passerelle',
    'archived_account_gateway' => 'Passerelle archivée avec succès',
    'archive_recurring_invoice' => 'Archiver facture récurrente',
    'archived_recurring_invoice' => 'Facture récurrente archivée avec succès',
    'delete_recurring_invoice' => 'Supprimer la facture récurrente',
    'deleted_recurring_invoice' => 'Facture récurrente supprimée avec succès',
    'restore_recurring_invoice' => 'Restaurer la facture récurrente',
    'restored_recurring_invoice' => 'Facture récurrente restaurée avec succès',
    'archive_recurring_quote' => 'Archiver devis récurrent',
    'archived_recurring_quote' => 'Devis récurrent archivé avec succès',
    'delete_recurring_quote' => 'Supprimer devis récurrent',
    'deleted_recurring_quote' => 'Devis récurrent supprimé avec succès',
    'restore_recurring_quote' => 'Restaurer devis récurrent',
    'restored_recurring_quote' => 'Devis récurrent restaurer avec succès',
    'archived' => 'Archivé',
    'untitled_account' => 'Société sans nom',
    'before' => 'Avant',
    'after' => 'Après',
    'reset_terms_help' => 'Remettre les conditions par défaut',
    'reset_footer_help' => 'Remettre le pied de facture par défaut',
    'export_data' => 'Exporter données',
    'user' => 'Utilisateur',
    'country' => 'Pays',
    'include' => 'Inclure',
    'logo_too_large' => 'Votre logo fait :size, pour de meilleures performance PDF nous vous suggérons d\'envoyer une image de moins de 200Ko',
    'import_freshbooks' => 'Importer depuis FreshBooks',
    'import_data' => 'Importer des données',
    'source' => 'Source',
    'csv' => 'CSV',
    'client_file' => 'Fichier de clients',
    'invoice_file' => 'Fichier de factures',
    'task_file' => 'Fichier de tâches',
    'no_mapper' => 'Mappage invalide pour ce fichier',
    'invalid_csv_header' => 'En-tête du fichier CSV invalide',
    'client_portal' => 'Portail client',
    'admin' => 'Admin',
    'disabled' => 'Désactivé',
    'show_archived_users' => 'Afficher les utilisateurs archivés',
    'notes' => 'Notes',
    'invoice_will_create' => 'la facture sera créée',
    'invoices_will_create' => 'les factures seront créées',
    'failed_to_import' => 'Les enregistrements suivants n\'ont pas pu être importés. Soit ils existent déjà, soit il leur manque des champs requis.',
    'publishable_key' => 'Clé publique',
    'secret_key' => 'Clé secrète',
    'missing_publishable_key' => 'Saisissez votre clé publique Stripe pour un processus de commande amélioré',
    'email_design' => 'Modèle de courriel',
    'due_by' => 'A échéance du :date',
    'enable_email_markup' => 'Activer le balisage',
    'enable_email_markup_help' => 'Rendez le règlement de vos clients plus facile en ajoutant les markup schema.org à vos courriels.',
    'template_help_title' => 'Aide Modèles',
    'template_help_1' => 'Variable disponibles :',
    'email_design_id' => 'Style de courriel',
    'email_design_help' => 'Rendez vos courriels plus professionnels avec des mises en page en HTML.',
    'plain' => 'Brut',
    'light' => 'Clair',
    'dark' => 'Sombre',
    'industry_help' => 'Utilisé dans le but de fournir des statistiques la taille et le secteur de l\'entreprise.',
    'subdomain_help' => 'Définissez un sous-domaine ou affichez la facture sur votre propre site web.',
    'website_help' => 'Afficher la facture dans un iFrame sur votre site web',
    'invoice_number_help' => 'Spécifier un préfixe ou utiliser un modèle personnalisé pour la création du numéro de facture.',
    'quote_number_help' => 'Spécifier un préfixe ou utiliser un modèle personnalisé pour la création du numéro de devis.',
    'custom_client_fields_helps' => 'Ajouter un champ lors de la création d\'un client et éventuellement afficher l\'étiquette et la valeur sur le PDF.',
    'custom_account_fields_helps' => 'Ajouter un label et une valeur aux détails de la société dur le PDF.',
    'custom_invoice_fields_helps' => 'Ajouter un champ lors de la création d\'une facture et éventuellement afficher l\'étiquette et la valeur sur le PDF.',
    'custom_invoice_charges_helps' => 'Ajouter une entrée de texte à la page de création/édition de devis et inclure le supplément au sous-toal de la facture.',
    'token_expired' => 'Validation jeton expiré. Veuillez réessayer.',
    'invoice_link' => 'Lien vers la facture',
    'button_confirmation_message' => 'Cliquez pour confirmer votre adresse e-mail.',
    'confirm' => 'Confirmer',
    'email_preferences' => 'Préférences de courriel',
    'created_invoices' => ':count facture(s) créée(s) avec succès',
    'next_invoice_number' => 'Le prochain numéro de facture est :number.',
    'next_quote_number' => 'Le prochain numéro de devis est :number.',
    'days_before' => 'jours avant le',
    'days_after' => 'jours après le',
    'field_due_date' => 'date d\'échéance',
    'field_invoice_date' => 'date de la facture',
    'schedule' => 'Planification',
    'email_designs' => 'Modèles de courriel',
    'assigned_when_sent' => 'Affecté lors de l\'envoi',
    'white_label_purchase_link' => 'Acheter une licence en marque blanche',
    'expense' => 'Dépense',
    'expenses' => 'Dépenses',
    'new_expense' => 'Saisir une dépense',
    'enter_expense' => 'Nouvelle dépense',
    'vendors' => 'Fournisseurs',
    'new_vendor' => 'Nouveau fournisseur',
    'payment_terms_net' => 'Net',
    'vendor' => 'Fournisseur',
    'edit_vendor' => 'Éditer le fournisseur',
    'archive_vendor' => 'Archiver ce fournisseur',
    'delete_vendor' => 'Supprimer ce fournisseur',
    'view_vendor' => 'Voir le fournisseur',
    'deleted_expense' => 'Dépense supprimée avec succès',
    'archived_expense' => 'Dépense archivée avec succès',
    'deleted_expenses' => 'Dépenses supprimées avec succès',
    'archived_expenses' => 'Dépenses archivées avec succès',
    'expense_amount' => 'Montant de la dépense',
    'expense_balance' => 'Solde de la dépense',
    'expense_date' => 'Date de la dépense',
    'expense_should_be_invoiced' => 'Cette dépense doit elle être facturée ?',
    'public_notes' => 'Note publique',
    'invoice_amount' => 'Montant de la facture',
    'exchange_rate' => 'Taux de change',
    'yes' => 'Oui',
    'no' => 'Non',
    'should_be_invoiced' => 'Devrait être facturé',
    'view_expense' => 'Voir la dépense # :expense',
    'edit_expense' => 'Éditer la dépensee',
    'archive_expense' => 'Archiver la dépense',
    'delete_expense' => 'Supprimer la dépense',
    'view_expense_num' => 'Dépense # :expense',
    'updated_expense' => 'Dépense mise à jour avec succès',
    'created_expense' => 'Dépense créée avec succès',
    'enter_expense' => 'Nouvelle dépense',
    'view' => 'Voir',
    'restore_expense' => 'Restaurer la dépense',
    'invoice_expense' => 'Facturer la dépense',
    'expense_error_multiple_clients' => 'La dépense ne peut pas être attribuée à plusieurs clients',
    'expense_error_invoiced' => 'La dépense à déjà été facturée',
    'convert_currency' => 'Convertir la devise',
    'num_days' => 'Nombre de jours',
    'create_payment_term' => 'Créer une condition de paiement',
    'edit_payment_terms' => 'Éditer condition de paiement',
    'edit_payment_term' => 'Éditer la condition de paiement',
    'archive_payment_term' => 'Archiver la condition de paiement',
    'recurring_due_dates' => 'Dates d\'échéance de facture récurrente',
    'recurring_due_date_help' => '<p>Définit automatiquement une date d\'échéance pour la facture.</p>
        <p>Les factures avec un cycle mensuel ou annuel définies pour être dues le jour ou avant le jour où elles sont créées seront dues le mois suivant. Les factures définies pour être dues le 29 ou le 30 dans des mois qui n\'ont pas ce jour seront dues le dernier jour du mois.</p>
        <p>Les factures avec un cycle hebdomadaire définies pour être dues le jour de la semaine où elles sont créées seront dues la semaine suivante.</p>
        <p>Par exemple :</p>
        <ul>
          <li>Aujourd\'hui est le 15, la date d\'échéance est le 1er du mois. La date d\'échéance devrait logiquement être le 1er du mois suivant.</li>
          <li>Aujourd\'hui est le 15, la date d\'échéance est le dernier jour du mois. La date d\'échéance sera le dernier jour de ce mois.
    </li>
          <li>Aujourd\'hui est le 15, la date d\'échéance est le 15ème jour du mois. La date d\'échéance sera le 15ème jour du mois <strong>suivant</strong>.
    </li>
          <li>Aujourd\'hui est le vendredi, la date d\'échéance est le 1er vendredi après. La date d\'échéance sera vendredi prochain, pas aujourd\'hui.
    </li>
        </ul>',
    'due' => 'Dû',
    'next_due_on' => 'Prochaine échéance : :date',
    'use_client_terms' => 'Utiliser les conditions de paiement du client',
    'day_of_month' => ':ordinal jour du mois',
    'last_day_of_month' => 'Dernier jour du mois',
    'day_of_week_after' => ':ordinal :day after',
    'sunday' => 'Dimanche',
    'monday' => 'Lundi',
    'tuesday' => 'Mardi',
    'wednesday' => 'Mercredi',
    'thursday' => 'Jeudi',
    'friday' => 'Vendredi',
    'saturday' => 'Samedi',
    'header_font_id' => 'Police de l\'en-tête',
    'body_font_id' => 'Police du corps',
    'color_font_help' => 'Note : la couleur et la police primaires sont également utilisées dans le portail client et le design des courriels.',
    'live_preview' => 'Aperçu',
    'invalid_mail_config' => 'Impossible d\'envoyer le mail, veuillez vérifier que les paramètres de messagerie sont corrects.',
    'invoice_message_button' => 'Pour visionner votre facture de :amount, cliquez sur le bouton ci-dessous.',
    'quote_message_button' => 'Pour visionner votre devis de :amount, cliquez sur le lien ci-dessous.',
    'payment_message_button' => 'Merci pour votre paiement de :amount.',
    'payment_type_direct_debit' => 'Prélèvement',
    'bank_accounts' => 'Comptes bancaires',
    'add_bank_account' => 'Ajouter un compte bancaire',
    'setup_account' => 'Paraméter le compte',
    'import_expenses' => 'Importer les dépenses',
    'bank_id' => 'Banque',
    'integration_type' => 'Type d\'intégration',
    'updated_bank_account' => 'Compte bancaire mis à jour avec succès',
    'edit_bank_account' => 'Éditer le compte bancaire',
    'archive_bank_account' => 'Archiver le compte bancaire',
    'archived_bank_account' => 'Compte bancaire archivé avec succès',
    'created_bank_account' => 'Compte bancaire créé avec succès',
    'validate_bank_account' => 'Valider le compte bancaire',
    'bank_password_help' => 'Note : votre mot de passe est transmis de manière sécurisée et jamais stocké sur nos serveurs',
    'bank_password_warning' => 'Attention: votre mot de passe peut être transmis en clair, pensez à activer HTTPS.',
    'username' => 'Nom d\'utilisateur',
    'account_number' => 'N° de compte',
    'account_name' => 'Nom du compte',
    'bank_account_error' => 'Impossible de récupérer les détails du compte, veuillez vérifier vos informations d\'identification.',
    'status_approved' => 'Approuvé',
    'quote_settings' => 'Paramètres des devis',
    'auto_convert_quote' => 'Convertir automatiquement',
    'auto_convert_quote_help' => 'Convertir automatiquement un devis en facture dès qu\'il est approuvé par le client.',
    'validate' => 'Valider',
    'info' => 'Info',
    'imported_expenses' => ':count_vendors fournisseur(s) et :count_expenses dépense(s) créé[e](s) avec succès',
    'iframe_url_help3' => 'Note : si vous prévoyez d\'accepter les cartes de crédit, nous vous recommandons d\'activer HTTPS sur votre site.',
    'expense_error_multiple_currencies' => 'Les dépenses ne peuvent avoir plusieurs devises.',
    'expense_error_mismatch_currencies' => 'La devise du client n\'est pas la même que celle de la dépense.',
    'trello_roadmap' => 'Feuille de route Trello',
    'header_footer' => 'En-tête/Pied de page',
    'first_page' => 'Première page',
    'all_pages' => 'Toutes les pages',
    'last_page' => 'Dernière page',
    'all_pages_header' => 'Voir les en-têtes sur',
    'all_pages_footer' => 'Voir les pieds de page sur',
    'invoice_currency' => 'Devise de la facture',
    'enable_https' => 'Nous vous recommandons fortement d\'activer le HTTPS si vous acceptez les paiements en ligne.',
    'quote_issued_to' => 'Devis à l\'attention de',
    'show_currency_code' => 'Code de la devise',
    'free_year_message' => 'Votre compte a été mis à niveau vers le plan pro pour une année sans frais.',
    'trial_message' => 'Votre compte va être crédité d\'un essai gratuit de 2 semaines de notre Plan pro.',
    'trial_footer' => 'Il vous reste :count jours d\'essai sur notre offre Pro, :link modifiez votre abonnement maintenant.',
    'trial_footer_last_day' => 'C\'est votre dernier jour d\'essai sur notre offre Pro, :link modifiez votre abonnement maintenant.',
    'trial_call_to_action' => 'Commencer l\'essai gratuit',
    'trial_success' => 'Crédit d\'un essai gratuit de 2 semaines de notre Plan pro avec succès',
    'overdue' => 'Impayé',


    'white_label_text' => 'Achetez une licence en marque blanche d\'UN AN au coût de $:price pour retirer la marque de Invoice Ninja des factures et du portail client.',
    'user_email_footer' => 'Pour modifier vos paramètres de notification par courriel, veuillez visiter :link',
    'reset_password_footer' => 'Si vous n\'avez pas effectué de demande de réinitalisation de mot de passe veuillez contacter notre support : :email',
    'limit_users' => 'Désolé, ceci excédera la limite de :limit utilisateurs',
    'more_designs_self_host_header' => 'Obtenez 6 modèles de factures additionnels pour seulement $:price',
    'old_browser' => 'Veuillez utiliser un :link',
    'newer_browser' => 'navigateur plus récent',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Connecter un compte bancaire pour importer automatiquement les dépenses et créer des fournisseurs. Supporte Amercian Express et :link.',
    'us_banks' => 'plus de 400 banques américaines',

    'pro_plan_remove_logo' => ':link pour supprimer le logo Invoice Ninja en souscrivant au Plan Pro',
    'pro_plan_remove_logo_link' => 'Cliquez ici',
    'invitation_status_sent' => 'Envoyé',
    'invitation_status_opened' => 'Ouvert',
    'invitation_status_viewed' => 'Consulté',
    'email_error_inactive_client' => 'Les courriels ne peuvent être envoyés aux clients inactifs',
    'email_error_inactive_contact' => 'Les courriels ne peuvent être envoyés aux contacts inactifs',
    'email_error_inactive_invoice' => 'Les courriels ne peuvent être envoyés aux factures inactives',
    'email_error_inactive_proposal' => 'Les courriels ne peuvent pas être envoyés aux propositions inactives',
    'email_error_user_unregistered' => 'Veuillez vous inscrire afin d\'envoyer des courriels',
    'email_error_user_unconfirmed' => 'Veuillez confirmer votre compte afin de permettre l\'envoi de courriels',
    'email_error_invalid_contact_email' => 'Adresse courriel du contact invalide',

    'navigation' => 'Navigation',
    'list_invoices' => 'Liste des factures',
    'list_clients' => 'Liste des clients',
    'list_quotes' => 'Liste des devis',
    'list_tasks' => 'Liste des tâches',
    'list_expenses' => 'Liste des dépenses',
    'list_recurring_invoices' => 'Liste des factures récurrentes',
    'list_payments' => 'Liste des paiements',
    'list_credits' => 'Liste des crédits',
    'tax_name' => 'Nom de la taxe',
    'report_settings' => 'Paramètres de rapport',
    'search_hotkey' => 'la racine est /',

    'new_user' => 'Nouvel utilisateur',
    'new_product' => 'Nouvel article',
    'new_tax_rate' => 'Nouveau taux de taxe',
    'invoiced_amount' => 'Montant de la facture',
    'invoice_item_fields' => 'Invoice Item Fields',
    'custom_invoice_item_fields_help' => 'Ajouter un champ lors de la création d\'un article de facture et afficher le libellé et la valeur sur le PDF.',
    'recurring_invoice_number' => 'Numéro récurrent',
    'recurring_invoice_number_prefix_help' => 'Spécifier un préfixe à ajouter au numéro de facture pour les factures récurrentes.',

    // Client Passwords
    'enable_portal_password' => 'Protéger les factures avec un mot de passe',
    'enable_portal_password_help' => 'Autoriser la création d\'un mot de passe pour chaque contact. Si un mot de passe est créé, le contact devra entrer un mot de passe avant de voir les factures.',
    'send_portal_password' => 'Générer automatiquement',
    'send_portal_password_help' => 'Si aucun mot de passe n\'est créé, un sera généré et envoyé avec la première facture.',

    'expired' => 'Expiré',
    'invalid_card_number' => 'Le numéro de carte bancaire est invalide.',
    'invalid_expiry' => 'La date d\'expiration est invalide.',
    'invalid_cvv' => 'Le code de sécurité est incorrect.',
    'cost' => 'Coût',
    'create_invoice_for_sample' => 'Note : créez votre première facture pour voir la prévisualisation ici.',

    // User Permissions
    'owner' => 'Propriétaire',
    'administrator' => 'Administrateur',
    'administrator_help' => 'Permettre à l\'utilisateur de gérer les utilisateurs, modifier les paramètres et de modifier tous les enregistrements',
    'user_create_all' => 'Créer des clients, des factures, etc.',
    'user_view_all' => 'Voir tous les clients, les factures, etc.',
    'user_edit_all' => 'Modifier tous les clients, les factures, etc.',
    'gateway_help_20' => ':link pour vous inscrire à Sage Pay.',
    'gateway_help_21' => ':link pour vous inscrire à Sage Pay.',
    'partial_due' => 'Solde partiel',
    'restore_vendor' => 'Restaurer le fournisseur',
    'restored_vendor' => 'Fournisseur restauré avec succès',
    'restored_expense' => 'Dépense restaurée avec succès',
    'permissions' => 'Permissions',
    'create_all_help' => 'Autoriser l\'utilisateur à créer et éditer tous les enregistrements',
    'view_all_help' => 'Autoriser l\'utilisateur à voir les enregistrements qu\'il n\'a pas créés',
    'edit_all_help' => 'Autoriser l\'utilisateur à modifier les enregistrements qu\'il n\'a pas créés',
    'view_payment' => 'Voir le paiement',

    'january' => 'Janvier',
    'february' => 'Février',
    'march' => 'Mars',
    'april' => 'Avril',
    'may' => 'Mai',
    'june' => 'Juin',
    'july' => 'Juillet',
    'august' => 'Août',
    'september' => 'Septembre',
    'october' => 'Octobre',
    'november' => 'Novembre',
    'december' => 'Décembre',

    // Documents
    'documents_header' => 'Documents :',
    'email_documents_header' => 'Documents :',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Documents de devis',
    'invoice_documents' => 'Documents de facture',
    'expense_documents' => 'Documents de dépense',
    'invoice_embed_documents' => 'Documents intégrés',
    'invoice_embed_documents_help' => 'Inclure l\'image attachée dans la facture.',
    'document_email_attachment' => 'Attacher les documents',
    'ubl_email_attachment' => 'Joindre UBL',
    'download_documents' => 'Télécharger les Documents (:size)',
    'documents_from_expenses' => 'Des dépenses :',
    'dropzone_default_message' => 'Glisser le fichier ou cliquer pour envoyer',
    'dropzone_default_message_disabled' => 'Envoi désactivé',
    'dropzone_fallback_message' => 'Votre navigateur ne supporte pas le drag\'n\'drop de fichier pour envoyer.',
    'dropzone_fallback_text' => 'Veuillez utiliser le formulaire ci-dessous pour charger vos fichiers à la veille façon.',
    'dropzone_file_too_big' => 'Fichier trop gros ({{filesize}}Mo). Max filesize: {{maxFilesize}}Mo.',
    'dropzone_invalid_file_type' => 'Vous ne pouvez pas envoyer de fichiers de ce type.',
    'dropzone_response_error' => 'Le serveur a répondu avec le code {{statusCode}}.',
    'dropzone_cancel_upload' => 'Annuler l\'envoi',
    'dropzone_cancel_upload_confirmation' => 'Etes-vous sûr de vouloir annuler cet envoi ?',
    'dropzone_remove_file' => 'Supprimer le fichier',
    'documents' => 'Documents',
    'document_date' => 'Date de Document',
    'document_size' => 'Taille',

    'enable_client_portal' => 'Portail client',
    'enable_client_portal_help' => 'Afficher/masquer le portail client.',
    'enable_client_portal_dashboard' => 'Tableau de bord',
    'enable_client_portal_dashboard_help' => 'Afficher/masquer la page du tableau de bord dans le portail client.',

    // Plans
    'account_management' => 'Gestion des comptes',
    'plan_status' => 'Statut du Plan',

    'plan_upgrade' => 'Mettre à niveau',
    'plan_change' => 'Changer de plan',
    'pending_change_to' => 'Change vers',
    'plan_changes_to' => ':plan au :date',
    'plan_term_changes_to' => ':plan (:term) le :date',
    'cancel_plan_change' => 'Annuler la modification',
    'plan' => 'Plan',
    'expires' => 'Expire',
    'renews' => 'Renouvellement',
    'plan_expired' => ':plan Plan Expiré',
    'trial_expired' => ':plan Essai du Plan terminé',
    'never' => 'Jamais',
    'plan_free' => 'Gratuit',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Entreprise',
    'plan_white_label' => 'Auto hébergé (Marque blanche)',
    'plan_free_self_hosted' => 'Auto hébergé (Gratuit)',
    'plan_trial' => 'Essai',
    'plan_term' => 'Terme',
    'plan_term_monthly' => 'Mensuel',
    'plan_term_yearly' => 'Annuel',
    'plan_term_month' => 'Mois',
    'plan_term_year' => 'An',
    'plan_price_monthly' => '$:price/Mois',
    'plan_price_yearly' => '$:price/An',
    'updated_plan' => 'Paramètres du plan mis à jour',
    'plan_paid' => 'Terme commencé',
    'plan_started' => 'Début du Plan',
    'plan_expires' => 'Fin du Plan',

    'white_label_button' => 'Marque blanche',

    'pro_plan_year_description' => 'Engagement d\'un an dans le Plan Invoice Ninja Pro.',
    'pro_plan_month_description' => 'Engagement d\'un mois dans le Plan Invoice Ninja Pro.',
    'enterprise_plan_product' => 'Plan Entreprise',
    'enterprise_plan_year_description' => 'Engagement d\'un an dans le Plan Invoice Ninja Entreprise.',
    'enterprise_plan_month_description' => 'Engagement d\'un mois dans le Plan Invoice Ninja Entreprise.',
    'plan_credit_product' => 'Crédit',
    'plan_credit_description' => 'Crédit pour temps inutilisé',
    'plan_pending_monthly' => 'Basculera en mensuel le :date',
    'plan_refunded' => 'Un remboursement a été émis.',

    'live_preview' => 'Aperçu',
    'page_size' => 'Taille de Page',
    'live_preview_disabled' => 'L\'aperçu en direct a été désactivé pour prendre en charge la police sélectionnée',
    'invoice_number_padding' => 'Remplissage',
    'preview' => 'Prévisualisation',
    'list_vendors' => 'Liste des fournisseurs',
    'add_users_not_supported' => 'Passez au Plan Enterprise pour ajouter des utilisateurs supplémentaires à votre compte.',
    'enterprise_plan_features' => 'Le plan entreprise ajoute le support pour de multiples utilisateurs ainsi que l\'ajout de pièces jointes, :link pour voir la liste complète des fonctionnalités.',
    'return_to_app' => 'Retourner à l\'App',


    // Payment updates
    'refund_payment' => 'Remboursement du paiement',
    'refund_max' => 'Max :',
    'refund' => 'Remboursement',
    'are_you_sure_refund' => 'Rembourser les paiements sélectionnés ?',
    'status_pending' => 'En attente',
    'status_completed' => 'Validé',
    'status_failed' => 'Échoué',
    'status_partially_refunded' => 'Remboursement partiel',
    'status_partially_refunded_amount' => ':amount remboursé',
    'status_refunded' => 'Remboursé',
    'status_voided' => 'Annulé',
    'refunded_payment' => 'Paiement remboursé',
    'activity_39' => ':user a annulé un paiement de :payment_amount (:payment)',
    'activity_40' => ':user a remboursé :adjustment d\'un paiement de :payment_amount (:payment)',
    'card_expiration' => 'Exp :&nbsp:expires',

    'card_creditcardother' => 'Inconnu',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accepter les transferts bancaires américains',
    'stripe_ach_help' => 'Le support de CCA (ACH) doit également être activé dans :link.',
    'ach_disabled' => 'Une autre passerelle est déjà configurée pour le prélèvement automatique.',

    'plaid' => 'Plaid',
    'client_id' => 'ID du client',
    'secret' => 'Clé secrète',
    'public_key' => 'Clé publique',
    'plaid_optional' => '(facultatif)',
    'plaid_environment_help' => 'Lorsqu\'une clé d\'essai Stripe est émise, l\'environnement (tartan) de développement Plaid est utilisé.',
    'other_providers' => 'Autres fournisseurs',
    'country_not_supported' => 'Ce pays n\'est pas géré par notre système.',
    'invalid_routing_number' => 'Le B.I.C. est invalide',
    'invalid_account_number' => 'Le numéro de compte bancaire est invalide',
    'account_number_mismatch' => 'Les numéros du compte bancaire ne correspondent pas.',
    'missing_account_holder_type' => 'Merci de saisir un compte particulier ou entreprise',
    'missing_account_holder_name' => 'Merci de saisir un nom de titulaire de compte',
    'routing_number' => 'B.I.C.',
    'confirm_account_number' => 'Confirmez votre numéro de compte bancaire',
    'individual_account' => 'Compte particulier',
    'company_account' => 'Compte entreprise',
    'account_holder_name' => 'Nom du titulaire du compte',
    'add_account' => 'Ajouter un compte',
    'payment_methods' => 'Moyen de paiement',
    'complete_verification' => 'Compléter la vérification',
    'verification_amount1' => 'Montant 1',
    'verification_amount2' => 'Montant 2',
    'payment_method_verified' => 'Vérification réussie',
    'verification_failed' => 'Vérification échouée',
    'remove_payment_method' => 'Supprimer le moyen de paiement',
    'confirm_remove_payment_method' => 'Souhaitez-vous vraiment retirer cette méthode de paiement ?',
    'remove' => 'Supprimer',
    'payment_method_removed' => 'Supprimer le moyen de paiement',
    'bank_account_verification_help' => 'Nous avons fait deux dépôts dans votre compte avec la description "VERIFICATION". Ces dépôts prendront 1-2 jours ouvrables pour apparaître sur votre relevé. Veuillez entrer les montants ci-dessous.',
    'bank_account_verification_next_steps' => 'Nous avons fait deux dépôts dans votre compte avec la description "VERIFICATION". Ces dépôts prendront 1-2 jours ouvrables pour apparaître sur votre relevé.
Lorsque les montant apparaîtront sur votre relevé, veuillez revenir sur cette page et cliquez sur "Compléter la vérification" à côté du compte.',
    'unknown_bank' => 'Banque inconnue',
    'ach_verification_delay_help' => 'Vous serez en mesure d\'utiliser le compte après avoir terminé la vérification. Celle-ci demande habituellement 1-2 jours ouvrables.',
    'add_credit_card' => 'Ajouter une carte de crédit',
    'payment_method_added' => 'Ajouter un moyen de paiement',
    'use_for_auto_bill' => 'Utiliser pour les factures automatiques',
    'used_for_auto_bill' => 'Méthode de paiement automatique de factures',
    'payment_method_set_as_default' => 'Définir une éthode de paiement automatique de factures',
    'activity_41' => 'Le paiement de :payment_amount a échoué (:payment)',
    'webhook_url' => 'URL Webhook',
    'stripe_webhook_help' => 'Vous devez :link.',
    'stripe_webhook_help_link_text' => 'ajouter cette URL comme un terminal avec Stripe',
    'gocardless_webhook_help_link_text' => 'ajouter cette URL comme point de terminaison dans GoCardless',
    'payment_method_error' => 'Une erreur s\'est produite en ajoutant votre méthode de paiement. Veuillez réessayer plus tard.',
    'notification_invoice_payment_failed_subject' => 'Le paiement a échoué pour la facture :invoice',
    'notification_invoice_payment_failed' => 'Un paiement fait par le client :client pour la facture :invoice à échoué.  Le paiement a été marqué comme échoué et :amount a été ajouté au solde du client.',
    'link_with_plaid' => 'Lier le compte instantanément avec Plaid',
    'link_manually' => 'Lier manuellement',
    'secured_by_plaid' => 'Sécurisé par Plaid',
    'plaid_linked_status' => 'Votre compte bancaire à :bank\'',
    'add_payment_method' => 'Ajouter une méthode de paiement',
    'account_holder_type' => 'Veuillez sélectionner le type de compte',
    'ach_authorization' => 'J\'autorise :company à utiliser mes données bancaires pour de futurs paiements, et si besoin de créditer mon compte par voie électronique afin de corriger d\'éventuelles erreurs de débits. Je comprends que je suis en mesure d\'annuler cette autorisation à tout moment en supprimant mon moyen de paiement ou en contactant :email.',
    'ach_authorization_required' => 'Vous devez consentir aux transactions ACH.',
    'off' => 'Fermé',
    'opt_in' => 'Désactivé',
    'opt_out' => 'Activé',
    'always' => 'Toujours',
    'opted_out' => 'Désactivé',
    'opted_in' => 'Activé',
    'manage_auto_bill' => 'Gérer les factures automatiques',
    'enabled' => 'Activé',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Activer les paiements PayPal via BrainTree',
    'braintree_paypal_disabled_help' => 'La passerelle PayPal traite les paiements PayPal',
    'braintree_paypal_help' => 'Vous devez aussi :link.',
    'braintree_paypal_help_link_text' => 'lier PayPal à votre compte BrainTree',
    'token_billing_braintree_paypal' => 'Sauvegarder les détails du paiement',
    'add_paypal_account' => 'Ajouter un compte PayPal',


    'no_payment_method_specified' => 'Aucune méthode de paiement spécifiée',
    'chart_type' => 'Type de graphique',
    'format' => 'Format',
    'import_ofx' => 'Importer OFX',
    'ofx_file' => 'Fichier OFX',
    'ofx_parse_failed' => 'Le traitement du fichier OFX a échoué',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'S\'enregistrer avec WePay',
    'use_another_provider' => 'Utiliser un autre fournisseur',
    'company_name' => 'Nom de l\'entreprise',
    'wepay_company_name_help' => 'Ceci apparaîtra sur le relevé de carte de crédit du client',
    'wepay_description_help' => 'Le but de ce compte.',
    'wepay_tos_agree' => 'J\'accepte les :link.',
    'wepay_tos_link_text' => 'Conditions d\'utilisation de WePay',
    'resend_confirmation_email' => 'Renvoyer le courriel de confirmation',
    'manage_account' => 'Gérer votre compte',
    'action_required' => 'Action requise',
    'finish_setup' => 'Terminer la configuration',
    'created_wepay_confirmation_required' => 'Veuillez vérifier votre courriel et confirmer votre adresse courriel avec WePay.',
    'switch_to_wepay' => 'Changer pour WePay',
    'switch' => 'Changer',
    'restore_account_gateway' => 'Rétablir la passerelle de paiement',
    'restored_account_gateway' => 'La passerelle de paiement a été  rétablie',
    'united_states' => 'États-Unis',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accepter les cartes de débit',
    'debit_cards' => 'Cartes de Débit',

    'warn_start_date_changed' => 'La prochaine facture sera envoyée à la nouvelle date spécifiée.',
    'warn_start_date_changed_not_sent' => 'La prochaine facture sera créée à la nouvelle date de début.',
    'original_start_date' => 'Première date de départ',
    'new_start_date' => 'Nouvelle date de départ',
    'security' => 'Sécurité',
    'see_whats_new' => 'Voir les nouveautés dans la version v:version',
    'wait_for_upload' => 'Veuillez patienter pendant le chargement  du fichier',
    'upgrade_for_permissions' => 'Adhérez à notre Plan entreprise pour activer les permissions.',
    'enable_second_tax_rate' => 'Activer la spécification d\'un <b>second taux de taxe</b>',
    'payment_file' => 'Fichier de paiement',
    'expense_file' => 'Fichier de dépense',
    'product_file' => 'Fichier de produit',
    'import_products' => 'Importer des produits',
    'products_will_create' => 'produits seront créés',
    'product_key' => 'Produit',
    'created_products' => ':count produit(s) créé(s)/mis à jour avec succès',
    'export_help' => 'Utilisez JSON si vous prévoyez d\'importer des données dans Invoice Ninja.<br/>Le fichier inclut les clients, les produits, les factures, les offres et les paiements.',
    'selfhost_export_help' => '<br/>Nous recommandons d\'utiliser mysqldump pour créer une sauvegarde complète.',
    'JSON_file' => 'Fichier JSON',

    'view_dashboard' => 'Afficher le tabeau de bord',
    'client_session_expired' => ' Session expirée.',
    'client_session_expired_message' => 'Votre session a expiré. Veuillez cliquer sur le lien dans votre courriel.',

    'auto_bill_notification' => 'Cette facture sera automatiquement facturée à votre :payment_method au dossier le :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'Compte bancaire',
    'auto_bill_payment_method_credit_card' => 'carte de crédit',
    'auto_bill_payment_method_paypal' => 'compte PayPal',
    'auto_bill_notification_placeholder' => 'Cette facture sera automatiquement facturée à votre carte de crédit inscrite au dossier à la date d\'échéance.',
    'payment_settings' => 'Paramètres de paiement',

    'on_send_date' => 'À la date d\'envoi',
    'on_due_date' => 'À la date d\'échéance',
    'auto_bill_ach_date_help' => 'ACH facturera toujours automatiquement à la date d\'échéance',
    'warn_change_auto_bill' => 'Selon les règles de NACHA, les changements à cette facture pourrait prévenir l\'autofacturation de ACH.',

    'bank_account' => 'Compte Bancaire',
    'payment_processed_through_wepay' => 'Les paiements ACH seront traités avec WePay.',
    'wepay_payment_tos_agree' => 'J\'accepte les :terms et la :privacy_policy de WePay',
    'privacy_policy' => 'Politique de confidentialité',
    'wepay_payment_tos_agree_required' => 'Vous devez accepter les conditions d\'utilisation et la politique de confidentialité de WePay',
    'ach_email_prompt' => 'Veuillez entrer votre adresse courriel:',
    'verification_pending' => 'En attente de vérification',

    'update_font_cache' => 'Veuillez actualiser la page pour mettre à jour le cache de la police de caractères',
    'more_options' => 'Plus d\'options',
    'credit_card' => 'Carte de Crédit',
    'bank_transfer' => 'Virement bancaire',
    'no_transaction_reference' => 'Nous n\'avons pas reçu de référence de transaction de paiement de la passerelle.',
    'use_bank_on_file' => 'Utiliser la banque inscrite au dossier',
    'auto_bill_email_message' => 'Cette facture sera automatiquement facturée à votre méthode de paiement inscrite au dossier à la date d\'échéance.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Ajouté le :date',
    'failed_remove_payment_method' => 'La suppression de la méthode de paiement a échoué',
    'gateway_exists' => 'La passerelle existe déjà',
    'manual_entry' => 'Saisie manuelle',
    'start_of_week' => 'Premier jour de la semaine',

    // Frequencies
    'freq_inactive' => 'Inactif',
    'freq_daily' => 'Quotidien',
    'freq_weekly' => 'Hebdomadaire',
    'freq_biweekly' => 'Bi-hebdomadaire',
    'freq_two_weeks' => 'Deux semaines',
    'freq_four_weeks' => 'Quatre semaines',
    'freq_monthly' => 'Mensuelle',
    'freq_three_months' => 'Trimestrielle',
    'freq_four_months' => 'Quatre mois',
    'freq_six_months' => 'Six mois',
    'freq_annually' => 'Annuelle',
    'freq_two_years' => 'Deux ans',

    // Payment types
    'payment_type_Apply Credit' => 'Appliquer le crédit',
    'payment_type_Bank Transfer' => 'Transfert bancaire',
    'payment_type_Cash' => 'Comptant',
    'payment_type_Debit' => 'Débit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Carte Visa',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Autre carte de crédit',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Chèque',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'Prélèvement automatique/domiciliation SEPA',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Comptabilité & Légal',
    'industry_Advertising' => 'Publicité',
    'industry_Aerospace' => 'Aérospatial',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automobile',
    'industry_Banking & Finance' => 'Banques & Finances',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Médiadiffusion',
    'industry_Business Services' => 'Services aux entreprises',
    'industry_Commodities & Chemicals' => 'Produits chimiques',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Informatique & Hightech',
    'industry_Defense' => 'Défense',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Divertissement',
    'industry_Government' => 'Gouvernement',
    'industry_Healthcare & Life Sciences' => 'Santé et sciences de la vie',
    'industry_Insurance' => 'Assurances',
    'industry_Manufacturing' => 'Production',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Médias',
    'industry_Nonprofit & Higher Ed' => 'Organisme sans but lucratif & Enseignement supérieur',
    'industry_Pharmaceuticals' => 'Pharmaceutique',
    'industry_Professional Services & Consulting' => 'Services Professionnels et Conseil',
    'industry_Real Estate' => 'Immobilier',
    'industry_Restaurant & Catering' => 'Restaurant & Traiteur',
    'industry_Retail & Wholesale' => 'Détail & Grossiste',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Voyage & Luxe',
    'industry_Other' => 'Autres',
    'industry_Photography' => 'Photographie',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albanie',
    'country_Antarctica' => 'Antartique',
    'country_Algeria' => 'Algérie',
    'country_American Samoa' => 'Samoa américaines',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua-et-Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentine',
    'country_Australia' => 'Australie',
    'country_Austria' => 'Autriche',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Arménie',
    'country_Barbados' => 'Barbades',
    'country_Belgium' => 'Belgique',
    'country_Bermuda' => 'Bermudes',
    'country_Bhutan' => 'Bhoutan',
    'country_Bolivia, Plurinational State of' => 'Bolivie',
    'country_Bosnia and Herzegovina' => 'Bosnie-Herzégovine',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Île Bouvet',
    'country_Brazil' => 'Brésil',
    'country_Belize' => 'Béize',
    'country_British Indian Ocean Territory' => 'Territoire britannique de l\'océan Indien',
    'country_Solomon Islands' => 'Iles Salomon',
    'country_Virgin Islands, British' => 'Îles Vierges britanniques',
    'country_Brunei Darussalam' => 'Brunei',
    'country_Bulgaria' => 'Bulgarie',
    'country_Myanmar' => 'Birmanie',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Biélorussie',
    'country_Cambodia' => 'Cambodge',
    'country_Cameroon' => 'Cameroun',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cap-Vert',
    'country_Cayman Islands' => 'Iles Cayman',
    'country_Central African Republic' => 'République Centrafricaine',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Tchad',
    'country_Chile' => 'Chili',
    'country_China' => 'Chine',
    'country_Taiwan, Province of China' => 'Taîwan',
    'country_Christmas Island' => 'Île Christmas',
    'country_Cocos (Keeling) Islands' => 'Îles Cocos (Keeling)',
    'country_Colombia' => 'Colombie',
    'country_Comoros' => 'Comores',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'République démocratique du Congo',
    'country_Cook Islands' => 'Îles Cook',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Coatie',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Chypre',
    'country_Czech Republic' => 'République tchèque',
    'country_Benin' => 'Bénin',
    'country_Denmark' => 'Danemark',
    'country_Dominica' => 'Dominique',
    'country_Dominican Republic' => 'République dominicaine',
    'country_Ecuador' => 'Équateur',
    'country_El Salvador' => 'Salvador',
    'country_Equatorial Guinea' => 'Guinée équatoriale',
    'country_Ethiopia' => 'Ethiopie',
    'country_Eritrea' => 'Érythrée',
    'country_Estonia' => 'Estonie',
    'country_Faroe Islands' => 'Îles Féroé',
    'country_Falkland Islands (Malvinas)' => 'Îles Malouines',
    'country_South Georgia and the South Sandwich Islands' => 'Géorgie du Sud-et-les Îles Sandwich du Sud',
    'country_Fiji' => 'Fidji',
    'country_Finland' => 'Finlande',
    'country_Åland Islands' => 'Åland',
    'country_France' => 'France',
    'country_French Guiana' => 'Guyane française',
    'country_French Polynesia' => 'Polynésie française',
    'country_French Southern Territories' => 'Terres australes et antarctiques françaises',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Géorgie',
    'country_Gambia' => 'Gambie',
    'country_Palestinian Territory, Occupied' => 'Territoires palestiniens occupés',
    'country_Germany' => 'Allemagne',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grèce',
    'country_Greenland' => 'Groenland',
    'country_Grenada' => 'Grenade',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinée',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Îles Heard-et-MacDonald',
    'country_Holy See (Vatican City State)' => 'Vatican',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hongrie',
    'country_Iceland' => 'Islande',
    'country_India' => 'Inde',
    'country_Indonesia' => 'Indonésie',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irlande',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italie',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaique',
    'country_Japan' => 'Japon',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordanie',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Corée du Nord',
    'country_Korea, Republic of' => 'Corée du Sud',
    'country_Kuwait' => 'Koweit',
    'country_Kyrgyzstan' => 'Kirghizistan',
    'country_Lao People\'s Democratic Republic' => 'Laos',
    'country_Lebanon' => 'Liban',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Lettonie',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libye',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuanie',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaisie',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malte',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritanie',
    'country_Mauritius' => 'Maurice',
    'country_Mexico' => 'Mexique',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolie',
    'country_Moldova, Republic of' => 'Moldavie',
    'country_Montenegro' => 'Monténégro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Maroc',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibie',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Népal',
    'country_Netherlands' => 'Pays-Bas',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Saint-Martin (partie Pays-Bas)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Pays-Bas caribéens',
    'country_New Caledonia' => 'Nouvelle-Calédonie',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nouvelle-Zélande',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Île Norfolk',
    'country_Norway' => 'Norvège',
    'country_Northern Mariana Islands' => 'Îles Mariannes du Nord',
    'country_United States Minor Outlying Islands' => 'Îles mineures éloignées des États-Unis',
    'country_Micronesia, Federated States of' => 'Micronésie',
    'country_Marshall Islands' => 'Îles Marshall',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papouasie-Nouvelle-Guinée',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Pérou',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Îles Pitcairn',
    'country_Poland' => 'Pologne',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinée-Bissau',
    'country_Timor-Leste' => 'Timor oriental',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'La Réunion',
    'country_Romania' => 'Roumanie',
    'country_Russian Federation' => 'Fédération Russe',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Sainte-Hélène, Ascension et Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint-Kitts-et-Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Sainte-Lucie',
    'country_Saint Martin (French part)' => 'Saint-Martin (partie française)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre et Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint-Vincent-et-les-Grenadines',
    'country_San Marino' => 'Saint-Marin',
    'country_Sao Tome and Principe' => 'Sao Tomé-et-Principe',
    'country_Saudi Arabia' => 'Arabie Saoudite',
    'country_Senegal' => 'Sénégal',
    'country_Serbia' => 'Serbie',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovaquie',
    'country_Viet Nam' => 'Viêt Nam',
    'country_Slovenia' => 'Slovénie',
    'country_Somalia' => 'Somalie',
    'country_South Africa' => 'Afrique du Sud',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Espagne',
    'country_South Sudan' => 'Soudan du Sud',
    'country_Sudan' => 'Soudan',
    'country_Western Sahara' => 'Sahara occidental',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard et Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Suède',
    'country_Switzerland' => 'Suisse',
    'country_Syrian Arab Republic' => 'Syrie',
    'country_Tajikistan' => 'Tadjikistan',
    'country_Thailand' => 'Thaïlande',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinité-et-Tobago',
    'country_United Arab Emirates' => 'Émirats arabes unis',
    'country_Tunisia' => 'Tunisie',
    'country_Turkey' => 'Turquie',
    'country_Turkmenistan' => 'Turkménistan',
    'country_Turks and Caicos Islands' => 'Îles Turques-et-Caïques',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Ouganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macédoine',
    'country_Egypt' => 'Egypte',
    'country_United Kingdom' => 'Royaume-Uni',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Île de Man',
    'country_Tanzania, United Republic of' => 'Tanzanie',
    'country_United States' => 'États-Unis',
    'country_Virgin Islands, U.S.' => 'Îles Vierges des États-Unis',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Ouzbékistan',
    'country_Venezuela, Bolivarian Republic of' => 'Vénézuela',
    'country_Wallis and Futuna' => 'Wallis et Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yémen',
    'country_Zambia' => 'Zambie',

    // Languages
    'lang_Brazilian Portuguese' => 'Portuguais - Brésil',
    'lang_Croatian' => 'Croate',
    'lang_Czech' => 'Tchèque',
    'lang_Danish' => 'Danois',
    'lang_Dutch' => 'Néerlandais',
    'lang_English' => 'Anglais',
    'lang_French' => 'Français',
    'lang_French - Canada' => 'Français - Canada',
    'lang_German' => 'Allemand',
    'lang_Italian' => 'Italien',
    'lang_Japanese' => 'Japonais',
    'lang_Lithuanian' => 'Lituanien',
    'lang_Norwegian' => 'Norvégien',
    'lang_Polish' => 'Polonais',
    'lang_Spanish' => 'Espagnol',
    'lang_Spanish - Spain' => 'Espagnol - Espagne',
    'lang_Swedish' => 'Suédois',
    'lang_Albanian' => 'Albanais',
    'lang_Greek' => 'Grec',
    'lang_English - United Kingdom' => 'Anglais - Royaume Uni',
    'lang_English - Australia' => 'Anglais - Australie',
    'lang_Slovenian' => 'Slovène',
    'lang_Finnish' => 'Finnois',
    'lang_Romanian' => 'Roumain',
    'lang_Turkish - Turkey' => 'Turc - Turquie',
    'lang_Portuguese - Brazilian' => 'Portugais - Brésil',
    'lang_Portuguese - Portugal' => 'Portugais - Portugal',
    'lang_Thai' => 'Thaïlandais',
    'lang_Macedonian' => 'Macedoine',
    'lang_Chinese - Taiwan' => 'Chine -Taiwan',
    'lang_Serbian' => 'Serbe',
    'lang_Bulgarian' => 'Bulgare',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Comptabilité & Légal',
    'industry_Advertising' => 'Publicité',
    'industry_Aerospace' => 'Aérospatial',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automobile',
    'industry_Banking & Finance' => 'Banques & Finances',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Médiadiffusion',
    'industry_Business Services' => 'Services aux entreprises',
    'industry_Commodities & Chemicals' => 'Produits chimiques',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Informatique & Hightech',
    'industry_Defense' => 'Défense',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Divertissement',
    'industry_Government' => 'Gouvernement',
    'industry_Healthcare & Life Sciences' => 'Santé et sciences de la vie',
    'industry_Insurance' => 'Assurances',
    'industry_Manufacturing' => 'Production',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Médias',
    'industry_Nonprofit & Higher Ed' => 'Organisme sans but lucratif & Enseignement supérieur',
    'industry_Pharmaceuticals' => 'Pharmaceutique',
    'industry_Professional Services & Consulting' => 'Services Professionnels et Conseil',
    'industry_Real Estate' => 'Immobilier',
    'industry_Retail & Wholesale' => 'Détail & Grossiste',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Voyage & Luxe',
    'industry_Other' => 'Autres',
    'industry_Photography' => 'Photographie',

    'view_client_portal' => 'Afficher le portail client',
    'view_portal' => 'Voir le portail',
    'vendor_contacts' => 'Contacts du fournisseur',
    'all' => 'Tous',
    'selected' => 'Sélectionné(s)',
    'category' => 'Catégorie',
    'categories' => 'Catégories',
    'new_expense_category' => 'Nouvelle catégorie de dépense',
    'edit_category' => 'Éditer la catégorie',
    'archive_expense_category' => 'Archiver la catégorie',
    'expense_categories' => 'catégories de dépense',
    'list_expense_categories' => 'Liste des catégories de dépense',
    'updated_expense_category' => 'Catégorie de dépense mise à jour avec succès',
    'created_expense_category' => 'Catégorie de dépense créée avec succès',
    'archived_expense_category' => 'Catégorie de dépense archivée avec succès',
    'archived_expense_categories' => ':count catégorie(s) de dépense archivée(s) avec succès',
    'restore_expense_category' => 'Restaurer la catégorie de dépense',
    'restored_expense_category' => 'Catégorie de dépense restaurée avec succès',
    'apply_taxes' => 'Appliquer les taxes',
    'min_to_max_users' => ':min à :max utilisateurs',
    'max_users_reached' => 'Le nombre maximum d\'utilisateurs a été atteint',
    'buy_now_buttons' => 'Boutons Achetez maintenant',
    'landing_page' => 'Page d\'accueil',
    'payment_type' => 'Type de paiement',
    'form' => 'Formulaire',
    'link' => 'Lien',
    'fields' => 'Champs',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Remarque : le client et la facture sont créés même si la transaction n\'est pas terminée.',
    'buy_now_buttons_disabled' => 'Cette fonctionnalité requiert qu\'un produit soit créé et qu\'une passerelle de paiement soit configurée.',
    'enable_buy_now_buttons_help' => 'Activer les boutons Achetez maintenant',
    'changes_take_effect_immediately' => 'Note : Les changements s\'appliquent immédiatement',
    'wepay_account_description' => 'Passerelle de paiement pour Invoice Ninja',
    'payment_error_code' => 'Il y a eu une erreur lors du traitement de paiement [:code]. Veuillez réessayer plus tard.',
    'standard_fees_apply' => 'Taux : 2.9%/1.2% [Carte de Crédit/Transfert Bancaire] + $0.30 par paiement réussit.',
    'limit_import_rows' => 'Les données nécessitent d\'être importées en lots de :count rangées ou moins.',
    'error_title' => 'Il y a eu une erreur',
    'error_contact_text' => 'Si vous avez besoin d\'aide, veuillez nous contacter à :mailaddress',
    'no_undo' => 'Avertissement: Ceci ne peut pas être annulé.',
    'no_contact_selected' => 'Veuillez sélectionner un contact',
    'no_client_selected' => 'Veuillez sélectionner un client',

    'gateway_config_error' => 'Cela pourrait aider de définir de nouveau mots de passe ou générer de nouvelles clés API.',
    'payment_type_on_file' => ':type enregistré',
    'invoice_for_client' => 'Facture :invoice pour :client',
    'intent_not_found' => 'Désolé, je ne comprends pas bien ce que vous souhaitez.',
    'intent_not_supported' => 'Désolé, je ne peux pas faire cela.',
    'client_not_found' => 'Je n\'ai pas pu trouver le client',
    'not_allowed' => 'Désolé, vous n\'avez pas les permissions requises',
    'bot_emailed_invoice' => 'Votre facture a été envoyée.',
    'bot_emailed_notify_viewed' => 'Recevez un courriel lorsqu\'elle sera vue.',
    'bot_emailed_notify_paid' => 'Recevez un courriel lorsqu\'elle sera payée.',
    'add_product_to_invoice' => 'Ajouter 1 :product',
    'not_authorized' => 'Vous n\'êtes pas autorisé(e)',
    'bot_get_email' => 'Salut! (wave)<br/>Merci d\'essayer le Bot Invoice Ninja.<br/>Vous devez créer un compte gratuit pour utiliser ce bot.<br/>Envoyez-moi l\'adresse courriel de votre compte pour commencer.',
    'bot_get_code' => 'Merci! Je vous ai envoyé un courriel avec votre code de sécurité.',
    'bot_welcome' => 'Ça y est, votre compte est vérifié.<br/>',
    'email_not_found' => 'Je n\'ai pas pu trouver un compte disponible pour :email',
    'invalid_code' => 'Le code n\'est pas valide',
    'security_code_email_subject' => 'Code de sécurité pour le Bot de Invoice Ninja',
    'security_code_email_line1' => 'Ceci est votre code de sécurité pour le Bot de Invoice Ninja.',
    'security_code_email_line2' => 'Note : il expirera dans 10 minutes.',
    'bot_help_message' => 'Je supporte actuellement:<br/>• Créer\mettre à jour\envoyer une facture<br/>• Lister les produits<br/>Par exemple:<br/><i>Facturer 2 billets à Simon, définir la date d\'échéance au prochain jeudi et l\'escompte à 10 %</i>',
    'list_products' => 'Afficher les produits',

    'include_item_taxes_inline' => 'Inclure une <b>ligne de taxes dans le total de la ligne',
    'created_quotes' => ':count offre(s) ont été créée(s)',
    'limited_gateways' => 'Note : Nous supportons une passerelle de carte de crédit par entreprise',

    'warning' => 'Avertissement',
    'self-update' => 'Mettre à jour',
    'update_invoiceninja_title' => 'Mettre à jour Invoice Ninja',
    'update_invoiceninja_warning' => 'Avant de commencer une mise à jour d\'Invoice Ninja, créez une sauvegarde de votre base de données et de vos fichiers!',
    'update_invoiceninja_available' => 'Une nouvelle version de Invoice Ninja est disponible.',
    'update_invoiceninja_unavailable' => 'Aucune mise à jour de Invoice Ninja disponible.',
    'update_invoiceninja_instructions' => 'Veuillez installer la nouvelle version <strong>:version</strong> en cliquant sur le bouton <em>Mettre à jour</em> ci-dessous. Ensuite, vous serez redirigé vers le tableau de bord.',
    'update_invoiceninja_update_start' => 'Mettre à jour maintenant',
    'update_invoiceninja_download_start' => 'Télécharger :version',
    'create_new' => 'Créer',

    'toggle_navigation' => 'Basculer la navigation',
    'toggle_history' => 'Basculer l\'historique',
    'unassigned' => 'Non assigné',
    'task' => 'Tâche',
    'contact_name' => 'Nom du contact',
    'city_state_postal' => 'Ville/ Province (Département)/ CP',
    'custom_field' => 'Champ personnalisé',
    'account_fields' => 'Champs pour entreprise',
    'facebook_and_twitter' => 'Facebook et Twitter',
    'facebook_and_twitter_help' => 'Suivez-nous pour nous soutenir notre projet',
    'reseller_text' => 'Remarque: la licence en marque blanche est destinée à un usage personnel, veuillez nous envoyer un courriel à: email si vous souhaitez revendre l\'application.',
    'unnamed_client' => 'Client sans nom',

    'day' => 'Jour',
    'week' => 'Semaine',
    'month' => 'Mois',
    'inactive_logout' => 'Vous avez été déconnecté en raison de l\'inactivité.',
    'reports' => 'Rapports',
    'total_profit' => 'Total des profits',
    'total_expenses' => 'Total des dépenses',
    'quote_to' => 'Offre pour',

    // Limits
    'limit' => 'Limite',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Aucune limite',
    'set_limits' => 'Définir les limites de :gateway_type',
    'enable_min' => 'Activer min',
    'enable_max' => 'Activer max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Cette facture ne correspond pas aux limites définies pour ce type de paiement.',

    'date_range' => 'Intervalle de dates',
    'raw' => 'Brut',
    'raw_html' => 'HTML brut',
    'update' => 'Mettre à jour',
    'invoice_fields_help' => 'Cliquez et déplacez les champs pour modifier leur ordre et emplacement',
    'new_category' => 'Nouvelle catégorie',
    'restore_product' => 'Rétablir le produit',
    'blank' => 'Vide',
    'invoice_save_error' => 'Il y a eu une erreur lors de la sauvegarde de votre facture',
    'enable_recurring' => 'Activer la récurrence',
    'disable_recurring' => 'Désactiver la récurrence',
    'text' => 'Texte',
    'expense_will_create' => 'la dépense sera créée',
    'expenses_will_create' => 'les dépenses seront créées',
    'created_expenses' => ':count dépense(s) créée(s)',

    'translate_app' => 'Aidez-nous à améliorer nos traductions avec :link',
    'expense_category' => 'Catégorie de dépense',

    'go_ninja_pro' => 'Passez au plan Ninja Pro!',
    'go_enterprise' => 'Passez au plan Enterprise!',
    'upgrade_for_features' => 'Mettre à jour pour plus de fonctionnalités',
    'pay_annually_discount' => 'Payez annuellement pour 10 mois + 2 gratuits',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'VotreMarque.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Personnalisez tous les aspects de votre facture',
    'enterprise_upgrade_feature1' => 'Définissez les permissions pour plusieurs utilisateurs',
    'enterprise_upgrade_feature2' => 'Ajoutez des fichiers joints aux factures et dépenses',
    'much_more' => 'Encore plus!',
    'all_pro_fetaures' => 'Plus toutes les fonctionnalités pro !',

    'currency_symbol' => 'Symbole',
    'currency_code' => 'Code',

    'buy_license' => 'Acheter une licence',
    'apply_license' => 'Activer la licence',
    'submit' => 'Envoyer',
    'white_label_license_key' => 'Clé de la licence',
    'invalid_white_label_license' => 'La licence en marque blanche n\'est pas valide',
    'created_by' => 'Créé par :name',
    'modules' => 'Modules',
    'financial_year_start' => 'Premier mois de l\'année',
    'authentication' => 'Authentification',
    'checkbox' => 'Case à cocher',
    'invoice_signature' => 'Signature',
    'show_accept_invoice_terms' => 'Case à cocher pour les conditions de facturation',
    'show_accept_invoice_terms_help' => 'Exiger que le client confirme qu\'il accepte les conditions de facturation',
    'show_accept_quote_terms' => 'Case à cocher pour les conditions d\'offre',
    'show_accept_quote_terms_help' => 'Exiger que le client confirme qu\'il accepte les conditions de l\'offre',
    'require_invoice_signature' => 'Signature de facture',
    'require_invoice_signature_help' => 'Exiger que le client signe',
    'require_quote_signature' => 'Signature de l\'offre',
    'require_quote_signature_help' => 'Exiger que le client signe',
    'i_agree' => 'J\'accepte les conditions ci dessus',
    'sign_here' => 'Veuillez signer ici:',
    'authorization' => 'Autorisation',
    'signed' => 'Signé',

    // BlueVine
    'bluevine_promo' => 'Obtenez des marges de crédit et d\'affacturages d\'affaires flexible en utilisant BlueVine.',
    'bluevine_modal_label' => 'Inscrivez-vous avec BlueVineInscrivez-vous avec BlueVine',
    'bluevine_modal_text' => '<h3>Finacement rapide pour votre entreprise. Pas de paperasse.</h3>
<ul><li>Marges de crédit et affacturage d\'affaires flexibles.</li></ul>',
    'bluevine_create_account' => 'Créer un compte',
    'quote_types' => 'Obtenir une offre pour',
    'invoice_factoring' => 'Affacturage',
    'line_of_credit' => 'Ligne de crédit',
    'fico_score' => 'Votre pointage de crédit',
    'business_inception' => 'Date de création de l\'entreprise',
    'average_bank_balance' => 'Solde moyen du compte bancaire',
    'annual_revenue' => 'Revenu annuel',
    'desired_credit_limit_factoring' => 'Affacturage désiré',
    'desired_credit_limit_loc' => 'Ligne de crédit désirée',
    'desired_credit_limit' => 'Limite de crédit désirée',
    'bluevine_credit_line_type_required' => 'Faites au moins un choix',
    'bluevine_field_required' => 'Ce champs est requis',
    'bluevine_unexpected_error' => 'Une erreur inattendue s\'est produite.',
    'bluevine_no_conditional_offer' => 'Vous devez fournir plus d\'information afin d\'obtenir une offre. Veuillez cliquer sur continuer ci-dessous.',
    'bluevine_invoice_factoring' => 'Affacturage',
    'bluevine_conditional_offer' => 'Offre conditionnelle',
    'bluevine_credit_line_amount' => 'Ligne de crédit',
    'bluevine_advance_rate' => 'Taux de l\'accompte',
    'bluevine_weekly_discount_rate' => 'Taux de remise hebdomadaire',
    'bluevine_minimum_fee_rate' => 'Frais minimaux',
    'bluevine_line_of_credit' => 'Ligne de crédit',
    'bluevine_interest_rate' => 'Taux d\'intérêts',
    'bluevine_weekly_draw_rate' => 'Taux hebdomadaire de retrait',
    'bluevine_continue' => 'Continuer vers BlueVine',
    'bluevine_completed' => 'Inscription avec BlueVine complétée',

    'vendor_name' => 'Fournisseur',
    'entity_state' => 'État',
    'client_created_at' => 'Date de création',
    'postmark_error' => 'Il y a eu un problème en envoyant le courriel par Postmark: :link',
    'project' => 'Projet',
    'projects' => 'Projets',
    'new_project' => 'Nouveau projet',
    'edit_project' => 'Editer le projet',
    'archive_project' => 'Archiver le projet',
    'list_projects' => 'Lister les projets',
    'updated_project' => 'Le projet a été mis à  jour avec succès',
    'created_project' => 'Le projet a été créé avec succès',
    'archived_project' => 'Le projet a été archivé avec succès',
    'archived_projects' => ':count projet(s) a (ont) été archivé(s)',
    'restore_project' => 'Restaurer le projet',
    'restored_project' => 'Le projet a été rétabli avec succès',
    'delete_project' => 'Effacer le Projet',
    'deleted_project' => 'Le projet a été supprimé avec succès',
    'deleted_projects' => ':count projet(s) a (ont) été supprimé(s) avec succès',
    'delete_expense_category' => 'Supprimer la catégorie',
    'deleted_expense_category' => 'La catégorie a été supprimée avec succès',
    'delete_product' => 'Effacer le Produit',
    'deleted_product' => 'Le produit a été supprimé avec succès',
    'deleted_products' => ':count produit(s) supprimé(s) avec succès',
    'restored_product' => 'Le produit a été rétabli avec succès',
    'update_credit' => 'Mettre à jour un crédit',
    'updated_credit' => 'Le crédit a été mis à jour avec succès',
    'edit_credit' => 'Éditer le crédit',
    'realtime_preview' => 'Aperçu en temps réel',
    'realtime_preview_help' => 'Επισκόπηση του νέου PDF που αναγράφεται στο τιμολόγιο σε πραγματικό χρόνο, κατά την έκδοση τιμολογίου. Απενεργοποιήστε αυτό για να βελτιώσετε την απόδοση κατά την έκδοση τιμολογίων. ',
    'live_preview_help' => 'Afficher un aperçu du PDF en direct sur la page de la facture.',
    'force_pdfjs_help' => 'Remplacer le lecteur PDF intégré dans :chrome_link et dans :firefox_link.<br/>Activez cette fonctionnalité si votre navigateur télécharge automatiquement les fichiers PDF.',
    'force_pdfjs' => 'Empêcher le téléchargement',
    'redirect_url' => 'URL de redirection',
    'redirect_url_help' => 'Indiquez si vous le souhaitez une URL à laquelle vous vouler rediriger après l\'entrée d\'un paiement.',
    'save_draft' => 'Sauvegarder le brouillon',
    'refunded_credit_payment' => 'Paiement de crédit remboursé',
    'keyboard_shortcuts' => 'Raccourcis clavier',
    'toggle_menu' => 'Basculer la navigation',
    'new_...' => 'Nouveau ...',
    'list_...' => 'Lister ...',
    'created_at' => 'Date de création',
    'contact_us' => 'Nous joindre',
    'user_guide' => 'Guide de l\'utilisateur',
    'promo_message' => 'Profitez de l\'offre d\'upgrade avant le :expires et épargnez :amount sur la première année de notre plan Pro ou Entreprise.',
    'discount_message' => 'L\'offre de :amount expire le :expires',
    'mark_paid' => 'Marquer comme payé',
    'marked_sent_invoice' => 'La facture marquée a été envoyée avec succès',
    'marked_sent_invoices' => 'Les factures marquées ont été envoyées avec succès',
    'invoice_name' => 'Facture',
    'product_will_create' => 'Le produit sera créé',
    'contact_us_response' => 'Merci pour votre message! Nous essaierons de répondre dès que possible. ',
    'last_7_days' => '7 derniers jours',
    'last_30_days' => '30 derniers jours',
    'this_month' => 'Mois en cours',
    'last_month' => 'Mois dernier',
    'current_quarter' => 'Trimestre courant',
    'last_quarter' => 'Dernier trimestre',
    'last_year' => 'Dernière année',
    'custom_range' => 'Intervalle personnalisé',
    'url' => 'URL',
    'debug' => 'Débogage',
    'https' => 'HTTPS',
    'require' => 'Obligatoire',
    'license_expiring' => 'Note: Votre licence va expirer dans :count jours, :link pour la renouveler.',
    'security_confirmation' => 'Votre adresse courriel a été confirmée.',
    'white_label_expired' => 'Votre licence en marque blanche a expiré. Merci de la renouveler pour soutenir notre projet.',
    'renew_license' => 'Renouveler la licence',
    'iphone_app_message' => 'Avez-vous pensé à télécharger notre :link ?',
    'iphone_app' => 'App iPhone',
    'android_app' => 'App Android',
    'logged_in' => 'Connecté',
    'switch_to_primary' => 'Veuillez basculer vers votre entreprise initiale (:name) pour gérer votre plan d\'abonnement.',
    'inclusive' => 'Inclusif',
    'exclusive' => 'Exclusif',
    'postal_city_state' => 'Ville/Province (Département)/Code postal',
    'phantomjs_help' => 'Dans certains cas, l\'application utilise :link_phantom pour générer le PDF. Installez :link_docs pour le générer localement.',
    'phantomjs_local' => 'Utilise PhantomJS local',
    'client_number' => 'Numéro de client',
    'client_number_help' => 'Spécifiez un préfixe ou utilisez un modèle personnalisé pour la création du numéro de client.',
    'next_client_number' => 'Le prochain numéro de client est :number',
    'generated_numbers' => 'Numéros générés',
    'notes_reminder1' => 'Premier rappel',
    'notes_reminder2' => 'Deuxième rappel',
    'notes_reminder3' => 'Troisième rappel',
    'notes_reminder4' => 'Rappel',
    'bcc_email' => 'Courriel CCI',
    'tax_quote' => 'Taxe applicable à l\'offre',
    'tax_invoice' => 'Taxe de facture',
    'emailed_invoices' => 'Les factures ont été envoyées par email avec succès',
    'emailed_quotes' => 'Les offres ont été envoyées par courriel avec succès',
    'website_url' => 'URL du site web',
    'domain' => 'Domaine',
    'domain_help' => 'Utilisé dans le portail du client et lors de l\'envoi de courriels',
    'domain_help_website' => 'Utilisé lors de l\'envoi de courriels',
    'import_invoices' => 'Importer des factures',
    'new_report' => 'Nouveau rapport',
    'edit_report' => 'Editer le rapport',
    'columns' => 'Colonnes',
    'filters' => 'Filtres',
    'sort_by' => 'Trier par',
    'draft' => 'Brouillon',
    'unpaid' => 'Non payé',
    'aging' => 'Vieillissement',
    'age' => 'Ancienneté',
    'days' => 'Jours',
    'age_group_0' => '0 - 30 jours',
    'age_group_30' => '30 -60 jours',
    'age_group_60' => '60 - 90 jours',
    'age_group_90' => '90 - 120 jours',
    'age_group_120' => '120+ jours',
    'invoice_details' => 'Détails de la facture',
    'qty' => 'Quantité',
    'profit_and_loss' => 'Profits et Pertes',
    'revenue' => 'Revenu',
    'profit' => 'Profit',
    'group_when_sorted' => 'Tri par groupe',
    'group_dates_by' => 'Regrouper les dates par',
    'year' => 'Année',
    'view_statement' => 'Voir le relevé',
    'statement' => 'Relevé',
    'statement_date' => 'Date du relevé',
    'mark_active' => 'Marquer comme actif',
    'send_automatically' => 'Envoyer automatiquement',
    'initial_email' => 'Courriel initial',
    'invoice_not_emailed' => 'Cette facture n\'a pas encore été envoyée par courriel.',
    'quote_not_emailed' => 'Ce devis n\'a pas encore été envoyé par courriel.',
    'sent_by' => 'Envoyé par :user',
    'recipients' => 'Destinataires',
    'save_as_default' => 'Sauvegarder par défaut',
    'start_of_week_help' => 'Utilisés par des sélecteurs de <b>date</b>',
    'financial_year_start_help' => 'Utilisés par des sélecteurs de <b>plages de date</b>',
    'reports_help' => 'MAJ + Clic pour filtrer plusieurs colonnes. CRTL + Clic pour annuler le groupement.',
    'this_year' => 'Cette année',

    // Updated login screen
    'ninja_tagline' => 'Créer. Envoyer. Être payé.',
    'login_or_existing' => 'Ou se connecter avec un compte connecté.',
    'sign_up_now' => 'Inscrivez-vous maintenant',
    'not_a_member_yet' => 'Pas encore membre ?',
    'login_create_an_account' => 'Créez un compte !',

    // New Client Portal styling
    'invoice_from' => 'Factures de :',
    'email_alias_message' => 'Chaque société doit avoir une adresse courriel unique.<br/>Envisagez d\'utiliser un alias. ie, courriel+label@example.com',
    'full_name' => 'Nom complet',
    'month_year' => 'MOIS/ANNEE',
    'valid_thru' => 'Valide\njusqu\'au',

    'product_fields' => 'Champs de produit',
    'custom_product_fields_help' => 'Ajoute un champ lors de la création d\'un produit ou d\'une facture et affiche l\'étiquette et la valeur sur le PDF.',
    'freq_two_months' => 'Deux mois',
    'freq_yearly' => 'Annuellement',
    'profile' => 'Profil',
    'payment_type_help' => 'Définit le <b>type de paiement manuel </b> par défaut.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Votre relevé',
    'statement_issued_to' => 'Relevé délivré à',
    'statement_to' => 'Relevé à',
    'customize_options' => 'Personnaliser les options',
    'created_payment_term' => 'Conditions de paiement créées avec succès',
    'updated_payment_term' => 'Conditions de paiement mises à jour avec succès',
    'archived_payment_term' => 'Conditions de paiement archivées avec succès',
    'resend_invite' => 'Renvoyer une invitation',
    'credit_created_by' => 'Le crédit a été créé par le paiement :transaction_reference',
    'created_payment_and_credit' => 'Le paiement et le crédit ont été créés avec succès',
    'created_payment_and_credit_emailed_client' => 'Le paiement et le crédit ont été créés et envoyés par courriel au client avec succès',
    'create_project' => 'Créer un projet',
    'create_vendor' => 'Créer un fournisseur',
    'create_expense_category' => 'Créer une catégorie',
    'pro_plan_reports' => ':link pour activer les rapports en joignant le Plan Pro',
    'mark_ready' => 'Marquer comme prêt',

    'limits' => 'Limites',
    'fees' => 'Frais',
    'fee' => 'Frais',
    'set_limits_fees' => 'Définir les limites/frais de :gateway_type',
    'fees_tax_help' => 'Activer les taxes par article pour définir les taux de taxes.',
    'fees_sample' => 'Le frais pour une facture de :amount serait de :total.',
    'discount_sample' => 'La réduction pour une facture de :amount serait de :total.',
    'no_fees' => 'Aucun frais',
    'gateway_fees_disclaimer' => 'Attention: tous les pays/passerelles de paiement n\'autorisent pas l\'ajout de frais. Consultez les conditions d\'utilisation de votre passerelle de paiement.',
    'percent' => 'Pourcent',
    'location' => 'Localisation',
    'line_item' => 'Ligne d\'article',
    'surcharge' => 'Majoration',
    'location_first_surcharge' => 'Activé - Première majoration',
    'location_second_surcharge' => 'Activé - Seconde majoration',
    'location_line_item' => 'Activer - Ligne d\'article',
    'online_payment_surcharge' => 'Majoration de paiement en ligne',
    'gateway_fees' => 'Frais de la passerelle',
    'fees_disabled' => 'Les frais sont désactivés',
    'gateway_fees_help' => 'Ajoute automatiquement une surcharge/remise de paiement en ligne.',
    'gateway' => 'Passerelle',
    'gateway_fee_change_warning' => 'S\'il existe des factures impayées avec des frais, elles doivent être mises à jour manuellement.',
    'fees_surcharge_help' => 'Personnaliser la majoration :link.',
    'label_and_taxes' => 'Libellé et taxes',
    'billable' => 'Facturable',
    'logo_warning_too_large' => 'Le fichier image est trop grand',
    'logo_warning_fileinfo' => 'Attention : Pour supporter les gifs, l\'extension PHP fileinfo doit être activée.',
    'logo_warning_invalid' => 'il y a eu un problème lors de la lecture du fichier image, merci d\'essayer un autre format.',

    'error_refresh_page' => 'Un erreur est survenue, merci de rafraîchir la page et essayer à nouveau',
    'data' => 'Données',
    'imported_settings' => 'Paramètres importés avec succès',
    'reset_counter' => 'Remettre le compteur à zéro',
    'next_reset' => 'Prochaine remise à zéro',
    'reset_counter_help' => 'Remettre automatiquement à zéro les compteurs de facture et de devis.',
    'auto_bill_failed' => 'La facturation automatique de :invoice_number a échouée.',
    'online_payment_discount' => 'Remise de paiement en ligne',
    'created_new_company' => 'La nouvelle entreprise a été créé avec succès',
    'fees_disabled_for_gateway' => 'Les frais sont désactivés pour cette passerelle.',
    'logout_and_delete' => 'Déconnexion/Suppression du compte',
    'tax_rate_type_help' => 'Lorsque sélectionné, les taux de taxes inclusifs ajustent le coût de l\'article de chaque ligne.<br/>Seulement les taux de taxes exclusifs peuvent être utilisé comme défaut.',
    'invoice_footer_help' => 'Utilisez $pageNumber et $pageCount pour afficher les informations de la page.',
    'credit_note' => 'Avoir',
    'credit_issued_to' => 'Crédit accordé à',
    'credit_to' => 'Crédit pour ',
    'your_credit' => 'Votre crédit',
    'credit_number' => 'Numéro d\'avoir',
    'create_credit_note' => 'Créer une note de crédit',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Erreur : La table de passerelle a des ID incorrectes.',
    'purge_data' => 'Purger les données',
    'delete_data' => 'Effacer les données',
    'purge_data_help' => 'Supprime toutes les données mais conserve le compte et les réglages',
    'cancel_account_help' => 'Supprime le compte ainsi que les données, les comptes et les réglages.',
    'purge_successful' => 'Les données de l\'entreprise ont été purgées avec succès',
    'forbidden' => 'Interdit',
    'purge_data_message' => 'Attention : Cette action va supprimer vos données et est irréversible',
    'contact_phone' => 'Téléphone du contact',
    'contact_email' => 'Courriel du contact',
    'reply_to_email' => 'Adresse de réponse',
    'reply_to_email_help' => 'Spécifier une adresse courriel de réponse',
    'bcc_email_help' => 'Inclut de façon privée cette adresse avec les courriels du client.',
    'import_complete' => 'L\'importation s\'est réalisée avec succès.',
    'confirm_account_to_import' => 'Confirmer votre compte pour l\'importation des données.',
    'import_started' => 'L\'importation est en cours. Vous recevrez un courriel lorsqu\'elle sera terminée.',
    'listening' => 'A l\'écoute...',
    'microphone_help' => 'Dire "nouvelle facture pour [client]" ou "montre-moi les paiements archivés pour [client]"',
    'voice_commands' => 'Commandes vocales',
    'sample_commands' => 'Exemples de commandes',
    'voice_commands_feedback' => 'Nous travaillons activement à l\'amélioration de cette fonctionnalité. Si vous souhaitez l\'ajout d\'une commande sépcifique, veuillez nous contacter par courriel à :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Mandat postal',
    'archived_products' => ':count produits archivés avec succès',
    'recommend_on' => 'Nous recommandons d\'<b>activer</b> ce réglage.',
    'recommend_off' => 'Nous recommandons de <b>désactiver</b> ce réglage.',
    'notes_auto_billed' => 'Auto-facturation',
    'surcharge_label' => 'Majoration',
    'contact_fields' => 'Champs de contact',
    'custom_contact_fields_help' => 'Ajouter un champ lors de la création d\'un contact et éventuellement afficher l\'étiquette et la valeur sur le PDF.',
    'datatable_info' => 'Affichage :start sur :end de :total entrées',
    'credit_total' => 'Total Crédit',
    'mark_billable' => 'Marquer facturable',
    'billed' => 'Facturé',
    'company_variables' => 'Variables de la compagnie',
    'client_variables' => 'Variables du client',
    'invoice_variables' => 'Variables de facture',
    'navigation_variables' => 'Variables de navigation',
    'custom_variables' => 'Variables personnalisées',
    'invalid_file' => 'Type de fichier invalide',
    'add_documents_to_invoice' => 'Ajouter un document à la facture',
    'mark_expense_paid' => 'Marquer payé',
    'white_label_license_error' => 'Validation de licence échouée, vérifier storage/logs/laravel-error.log pour plus de détails.',
    'plan_price' => 'Prix du Plan',
    'wrong_confirmation' => 'Code de confirmation incorrect',
    'oauth_taken' => 'Le compte est déjà enregistré',
    'emailed_payment' => 'Paiement envoyé par email avec succès',
    'email_payment' => 'Reçu du paiement par courriel',
    'invoiceplane_import' => 'Utiliser: :link pour migrer vos données depuis InvoicePlane',
    'duplicate_expense_warning' => 'Attention: Ce :link est peut être un doublon',
    'expense_link' => 'Dépenses',
    'resume_task' => 'Relancer la tâche',
    'resumed_task' => 'Tâche relancée avec succès',
    'quote_design' => 'Mise en page des Devis',
    'default_design' => 'Conception standard',
    'custom_design1' => 'Modèle personnalisé 1',
    'custom_design2' => 'Modèle personnalisé 2',
    'custom_design3' => 'Modèle personnalisé 3',
    'empty' => 'Vide',
    'load_design' => 'Charger un modèle',
    'accepted_card_logos' => 'Logos des cartes acceptées',
    'phantomjs_local_and_cloud' => 'Utilisation locale de PhantomJS, retombant à phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Clé Analytics',
    'analytics_key_help' => 'Suivez les paiements en utilisant :link',
    'start_date_required' => 'La date de début est requise',
    'application_settings' => 'Paramètres de l\'application',
    'database_connection' => 'Connexion base de donnée',
    'driver' => 'Pilote',
    'host' => 'Domaine',
    'database' => 'Base de données',
    'test_connection' => 'Tester la connexion',
    'from_name' => 'Nom expéditeur',
    'from_address' => 'Adresse expéditeur',
    'port' => 'Port',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Domaine Mailgun',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Envoyer un courriel de test',
    'select_label' => 'Sélection intitulé',
    'label' => 'Intitulé',
    'service' => 'Service',
    'update_payment_details' => 'Mettre à jour les détails de paiement',
    'updated_payment_details' => 'Détails de paiement mis à jour avec succès',
    'update_credit_card' => 'Mettre à jour une carte de crédit',
    'recurring_expenses' => 'Dépenses récurrentes',
    'recurring_expense' => 'Dépense récurrente',
    'new_recurring_expense' => 'Nouvelle dépense récurrente',
    'edit_recurring_expense' => 'Éditer la dépense récurrente',
    'archive_recurring_expense' => 'Archiver la dépense récurrente',
    'list_recurring_expense' => 'Liste des dépenses récurrentes',
    'updated_recurring_expense' => 'Dépense récurrente mise à jour avec succès',
    'created_recurring_expense' => 'Dépense récurrente créée avec succès',
    'archived_recurring_expense' => 'Dépense récurrente archivée avec succès',
    'restore_recurring_expense' => 'Restaurer la dépense récurrente',
    'restored_recurring_expense' => 'Dépense récurrente restaurée avec succès',
    'delete_recurring_expense' => 'Supprimer la dépense récurrente',
    'deleted_recurring_expense' => 'Projet supprimé avec succès',
    'view_recurring_expense' => 'Voir la dépense récurrente',
    'taxes_and_fees' => 'Taxes et frais',
    'import_failed' => 'L\'importation a échoué',
    'recurring_prefix' => 'Préfixe récurrent',
    'options' => 'Options',
    'credit_number_help' => 'Spécifier un préfixe ou utiliser un motif personnalisé pour définir dynamiquement le numéro de crédit pour les factures négatives.',
    'next_credit_number' => 'Le prochain numéro de crédit est :number',
    'padding_help' => 'Le nombre de zéro(s) pour remplir le numéro.',
    'import_warning_invalid_date' => 'Attention : Le format de la date semble être invalide.',
    'product_notes' => 'Notes de produit',
    'app_version' => 'Version de l\'App',
    'ofx_version' => 'Version OFX',
    'gateway_help_23' => ':link pour obtenir vos clés d\'API Stripe.',
    'error_app_key_set_to_default' => 'Erreur: APP_KEY est défini avec une valeur par défaut. Pour la mettre à jour, faite une sauvegarde de votre base de données et exécutez <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Faire payer des frais de retard',
    'late_fee_amount' => 'Montant de pénalité de retard',
    'late_fee_percent' => 'Pourcentage de pénalité de retard',
    'late_fee_added' => 'Frais de retard ajoutés le :date',
    'download_invoice' => 'Télécharger la facture',
    'download_quote' => 'Télécharger le devis',
    'invoices_are_attached' => 'Votre devis en PDF est en pièce jointe',
    'downloaded_invoice' => 'Un courriel sera envoyé avec le PDF de la facture',
    'downloaded_quote' => 'Un courriel sera envoyé avec le PDF du devis',
    'downloaded_invoices' => 'Un courriel sera envoyé avec les PDFs de la facture',
    'downloaded_quotes' => 'Un courriel sera envoyé avec les PDFs du devis',
    'clone_expense' => 'Dupliquer la dépense',
    'default_documents' => 'Documents par défaut',
    'send_email_to_client' => 'Envoyer un courriel au client',
    'refund_subject' => 'Remboursement traité',
    'refund_body' => 'Vous avez été remboursé du montant de :amount pour la facture :invoice_number.',

    'currency_us_dollar' => 'Dollar américain',
    'currency_british_pound' => 'Livre anglaise',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Rand sud-africain',
    'currency_danish_krone' => 'Couronne danoise',
    'currency_israeli_shekel' => 'Shekel israélien',
    'currency_swedish_krona' => 'Couronne suédoise',
    'currency_kenyan_shilling' => 'Shilling kényan',
    'currency_canadian_dollar' => 'Dollar canadien',
    'currency_philippine_peso' => 'Peso philippin',
    'currency_indian_rupee' => 'Roupie indienne',
    'currency_australian_dollar' => 'Dollar australien',
    'currency_singapore_dollar' => 'Dollar singapourien',
    'currency_norske_kroner' => 'Couronne norvégienne',
    'currency_new_zealand_dollar' => 'Dollar néo-zélandais',
    'currency_vietnamese_dong' => 'Dong vietnamien',
    'currency_swiss_franc' => 'Franc suisse',
    'currency_guatemalan_quetzal' => 'Quetzal guatémaltais',
    'currency_malaysian_ringgit' => 'Ringgit malaisien',
    'currency_brazilian_real' => 'Réal brésilien',
    'currency_thai_baht' => 'Baht thailandais',
    'currency_nigerian_naira' => 'Naira nigérian',
    'currency_argentine_peso' => 'Peso argentin',
    'currency_bangladeshi_taka' => 'Taka bangladais',
    'currency_united_arab_emirates_dirham' => 'Dirham émirati',
    'currency_hong_kong_dollar' => 'Dollar hongkongais',
    'currency_indonesian_rupiah' => 'Rupiah indonésienne',
    'currency_mexican_peso' => 'Peso mexicain',
    'currency_egyptian_pound' => 'Livre égyptienne',
    'currency_colombian_peso' => 'Peso colombien',
    'currency_west_african_franc' => 'Franc CFA',
    'currency_chinese_renminbi' => 'Renminbi chinois',
    'currency_rwandan_franc' => 'Franc rwandais',
    'currency_tanzanian_shilling' => 'Shilling tanzanien',
    'currency_netherlands_antillean_guilder' => 'Florin antillais',
    'currency_trinidad_and_tobago_dollar' => 'Dollar trinidadien',
    'currency_east_caribbean_dollar' => 'Dollar est-caribéen',
    'currency_ghanaian_cedi' => 'Cedi ghanéen',
    'currency_bulgarian_lev' => 'Lev bulgare',
    'currency_aruban_florin' => 'Florin arubais',
    'currency_turkish_lira' => 'Livre turque',
    'currency_romanian_new_leu' => 'Leu roumain',
    'currency_croatian_kuna' => 'Kuna croate',
    'currency_saudi_riyal' => 'Riyal saoudien',
    'currency_japanese_yen' => 'Yen japonais',
    'currency_maldivian_rufiyaa' => 'Rufiyaa maldivienne',
    'currency_costa_rican_colon' => 'Colon costaricien',
    'currency_pakistani_rupee' => 'Roupie pakistanaise',
    'currency_polish_zloty' => 'Złoty polonais',
    'currency_sri_lankan_rupee' => 'Roupie srilankaise',
    'currency_czech_koruna' => 'Couronne tchèque',
    'currency_uruguayan_peso' => 'Peso uruguayen',
    'currency_namibian_dollar' => 'Dollar namibien',
    'currency_tunisian_dinar' => 'Dinar tunisien',
    'currency_russian_ruble' => 'Rouble russe',
    'currency_mozambican_metical' => 'Metical mozambicain',
    'currency_omani_rial' => 'Rial omanais',
    'currency_ukrainian_hryvnia' => 'Hryvnia ukrainienne',
    'currency_macanese_pataca' => 'Pataca macanaise',
    'currency_taiwan_new_dollar' => 'Dollar taïwanais',
    'currency_dominican_peso' => 'Peso dominicain',
    'currency_chilean_peso' => 'Peso chilien',
    'currency_icelandic_krona' => 'Couronne islandaise',
    'currency_papua_new_guinean_kina' => 'Kina de Papouasie-Nouvelle-Guinée',
    'currency_jordanian_dinar' => 'Dinar jordanien',
    'currency_myanmar_kyat' => 'Kyat myanmarais',
    'currency_peruvian_sol' => 'Sol péruvien',
    'currency_botswana_pula' => 'Pula botswanais',
    'currency_hungarian_forint' => 'Forint hongrois',
    'currency_ugandan_shilling' => 'Shilling ougandais',
    'currency_barbadian_dollar' => 'Dollar barbadien',
    'currency_brunei_dollar' => 'Dollar de Brunei',
    'currency_georgian_lari' => 'Lari grégorien',
    'currency_qatari_riyal' => 'Rial Qatari',
    'currency_honduran_lempira' => 'Lempira hondurien',
    'currency_surinamese_dollar' => 'Dollar du Suriname',
    'currency_bahraini_dinar' => 'Dinar bahreïni',
    'currency_venezuelan_bolivars' => 'Bolivar fort',
    'currency_south_korean_won' => 'Won sud-coréen',
    'currency_moroccan_dirham' => 'Dirham marocain',
    'currency_jamaican_dollar' => 'Dollar jamaicain',
    'currency_angolan_kwanza' => 'Kwanza angolais',
    'currency_haitian_gourde' => 'Gourde haïtienne',
    'currency_zambian_kwacha' => 'Kwacha zambien',
    'currency_nepalese_rupee' => 'Roupie népalaise',
    'currency_cfp_franc' => 'Franc CFP',
    'currency_mauritian_rupee' => 'Roupie mauricienne',
    'currency_cape_verdean_escudo' => 'Escudo cap-verdien',
    'currency_kuwaiti_dinar' => 'Dinar koweïtien',
    'currency_algerian_dinar' => 'Dinar algérien',
    'currency_macedonian_denar' => 'Denar macédonien',
    'currency_fijian_dollar' => 'Dollar de Fidji',
    'currency_bolivian_boliviano' => 'Boliviano bolivien',
    'currency_albanian_lek' => 'Lek albanais',
    'currency_serbian_dinar' => 'Dinar serbe',
    'currency_lebanese_pound' => 'Livre libanaise',
    'currency_armenian_dram' => 'Dram arménien',
    'currency_azerbaijan_manat' => 'Manat azerbaïdjanais',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Mark convertible de Bosnie-Herzégovine',
    'currency_belarusian_ruble' => 'Rouble biélorusse',
    'currency_moldovan_leu' => 'Leu moldave',
    'currency_kazakhstani_tenge' => 'Tenge kazakh',
    'currency_gibraltar_pound' => 'Livre de Gibraltar',

    'review_app_help' => 'Nous espérons que votre utilisation de cette application vous est agréable.<br/>Un commentaire de votre part serait grandement apprécié!',
    'writing_a_review' => 'écrire un commentaire',

    'use_english_version' => 'Assurez vous d\'utiliser la version anglaise du fichier.<br/>Nous utilisons le titre de colonne pour identifier les champs.',
    'tax1' => 'Première taxe',
    'tax2' => 'Seconde taxe',
    'fee_help' => 'Les frais de la passerelle sont les coûts facturés pour l\'accès aux réseaux financiers qui traitent le traitement des paiements en ligne.',
    'format_export' => 'Format d\'exportation',
    'custom1' => 'Personnalisé1',
    'custom2' => 'Personnalisé2',
    'contact_first_name' => 'Prénom du contact',
    'contact_last_name' => 'Nom du contact',
    'contact_custom1' => 'Premier champ de contact personnalisé ',
    'contact_custom2' => 'Second champ de contact personnalisé',
    'currency' => 'Devise',
    'ofx_help' => 'Pour résoudre un problème, consultez les commentaires sur :ofxhome_link et testez avec :ofxget_link.',
    'comments' => 'commentaires',

    'item_product' => 'Produit de l\'article',
    'item_notes' => 'Notes de l\'article',
    'item_cost' => 'Coût de l\'article',
    'item_quantity' => 'Quantité de l\'article',
    'item_tax_rate' => 'Taux de taxe de l\'article',
    'item_tax_name' => 'Nom de taxe de l\'article',
    'item_tax1' => 'Taxe 1 de l\'article',
    'item_tax2' => 'Taxe 2 de l\'article',

    'delete_company' => 'Supprimer la société',
    'delete_company_help' => 'Supprime définitivement la société avec toutes ses données et paramètres.',
    'delete_company_message' => 'Attention : Ceci supprimera définitivement votre société, il n\'y a pas d\'annulation.',

    'applied_discount' => 'Le coupon a été appliqué ; le prix du plan a été réduit de :discount %.',
    'applied_free_year' => 'Le coupon a été appliqué ; votre compte a été mis à niveau vers pro pour une année.',

    'contact_us_help' => 'Si vous devez rapporter une erreur, veuillez inclure toute information pertinente que vous trouverez dans les fichiers logs à storage/logs/laravel-error.log',
    'include_errors' => 'Inclure les erreurs',
    'include_errors_help' => 'Inclure le :link de storage/logs/laravel-error.log',
    'recent_errors' => 'erreurs récentes',
    'customer' => 'Client',
    'customers' => 'Clients',
    'created_customer' => 'Client créé avec succès',
    'created_customers' => ':count clients créés avec succès',

    'purge_details' => 'Les données dans votre entreprise (:account) ont été purgées avec succès.',
    'deleted_company' => 'Société supprimée avec succès',
    'deleted_account' => 'Compte annulé avec succès',
    'deleted_company_details' => 'Votre entreprise (:account) a été supprimée avec succès.',
    'deleted_account_details' => 'Votre compte (:account) a été supprimé avec succès.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'Prélèvement automatique/domiciliation SEPA',
    'enable_alipay' => 'Accepter Alipay',
    'enable_sofort' => 'Accepter les transferts bancaires européens',
    'stripe_alipay_help' => 'Ces passerelles doivent aussi être activées dans :link.',
    'calendar' => 'Calendrier',
    'pro_plan_calendar' => ':link pour activer le calendrier en joignant le Plan Pro',

    'what_are_you_working_on' => 'Sur quoi travaillez-vous ?',
    'time_tracker' => 'Suivi du temps',
    'refresh' => 'Rafraîchir',
    'filter_sort' => 'Filtrer/Trier',
    'no_description' => 'Aucune description',
    'time_tracker_login' => 'Connexion au suivi du temps',
    'save_or_discard' => 'Enregistrer ou ignorer vos modifications',
    'discard_changes' => 'Ignorer les modifications',
    'tasks_not_enabled' => 'Les tâches ne sont pas activées.',
    'started_task' => 'Tâche démarrée avec succès',
    'create_client' => 'Créer un client',

    'download_desktop_app' => 'Télécharger l\'application de bureau',
    'download_iphone_app' => 'Télécharger l\'app iPhone',
    'download_android_app' => 'Télécharger l\'app Android',
    'time_tracker_mobile_help' => 'Double-cliquez une tâche pour la sélectionner',
    'stopped' => 'Arrêté',
    'ascending' => 'Ascendant',
    'descending' => 'Descendant',
    'sort_field' => 'Trier par',
    'sort_direction' => 'Direction',
    'discard' => 'Ignorer',
    'time_am' => 'du matin',
    'time_pm' => 'du soir',
    'time_mins' => 'min',
    'time_hr' => 'h',
    'time_hrs' => 'h',
    'clear' => 'Effacer',
    'warn_payment_gateway' => 'Note : Une passerelle de paiement est requise pour accepter les règlements en ligne, :link pour en ajouter une.',
    'task_rate' => 'Taux de tâche',
    'task_rate_help' => 'Définir le taux par défaut pour les tâches facturées.',
    'past_due' => 'En retard',
    'document' => 'Document',
    'invoice_or_expense' => 'Facture/Dépense',
    'invoice_pdfs' => 'PDFs de facture',
    'enable_sepa' => 'Accepter SEPA',
    'enable_bitcoin' => 'Accepter Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'En fournissant votre IBAN et en confirmant ce paiement, vous autorisez :company et Stripe, notre fournisseur de service de paiement, à envoyer une demande à votre institution bancaire pour un prélèvement sur votre compte conformément à ces instructions. Vous pouvez demander un remboursement à votre institution bancaire selon les conditions de votre entente avec institution bancaire. Une demande de remboursement doit être faite dans les 8 semaines à partir du jour de la transaction.',
    'recover_license' => 'Récupérer la licence',
    'purchase' => 'Acheter',
    'recover' => 'Récupérer',
    'apply' => 'Appliquer',
    'recover_white_label_header' => 'Récupérer la licence marque blanche',
    'apply_white_label_header' => 'Appliquer la licence marque blanche',
    'videos' => 'Vidéos',
    'video' => 'Vidéo',
    'return_to_invoice' => 'Retourner à la facture',
    'gateway_help_13' => 'Pour utiliser ITN, laissez le champ de la clé PDT vide.',
    'partial_due_date' => 'Paiement partiel',
    'task_fields' => 'Champs de tâche',
    'product_fields_help' => 'Glissez et déposez les champs pour changer leur ordre',
    'custom_value1' => 'Valeur Personnalisée 1',
    'custom_value2' => 'Valeur Personnalisée 2',
    'enable_two_factor' => 'Authentification à 2 facteurs',
    'enable_two_factor_help' => 'Utilisez votre téléphone pour confirmer votre identité lorsque vous vous connectez',
    'two_factor_setup' => 'Configuration à deux facteurs',
    'two_factor_setup_help' => 'Scannez le code à barres avec une application compatible :link',
    'one_time_password' => 'Mot de passe à usage unique',
    'set_phone_for_two_factor' => 'Définissez votre numéro de téléphone mobile comme une sauvegarde pour activer.',
    'enabled_two_factor' => 'Authentification à deux facteurs activée avec succès',
    'add_product' => 'Ajouter un produit',
    'email_will_be_sent_on' => 'Note : le courriel sera envoyé le :date.',
    'invoice_product' => 'Facturer le produit',
    'self_host_login' => 'Connexion de l\'auto-hébergement',
    'set_self_hoat_url' => 'URL de l\'auto-hébergement',
    'local_storage_required' => 'Erreur : le stockage local n\'est pas disponible.',
    'your_password_reset_link' => 'Votre lien de réinitialisation de mot de passe',
    'subdomain_taken' => 'Le sous-domaine est déjà utilisé',
    'client_login' => 'Connexion client',
    'converted_amount' => 'Montant converti',
    'default' => 'Par défaut',
    'shipping_address' => 'Adresse de Livraison',
    'bllling_address' => 'Adresse de Facturation',
    'billing_address1' => 'Rue',
    'billing_address2' => 'Appt/Bâtiment',
    'billing_city' => 'Ville',
    'billing_state' => 'Région/Département',
    'billing_postal_code' => 'Code postal',
    'billing_country' => 'Pays',
    'shipping_address1' => 'Rue',
    'shipping_address2' => 'Appt/Bâtiment',
    'shipping_city' => 'Ville',
    'shipping_state' => 'Région/Département',
    'shipping_postal_code' => 'Code postal',
    'shipping_country' => 'Pays',
    'classify' => 'Classification',
    'show_shipping_address_help' => 'Exiger du client qu\'il fournisse une adresse de livraison.',
    'ship_to_billing_address' => 'Livrer à l\'adresse de facturation',
    'delivery_note' => 'Bon de livraison',
    'show_tasks_in_portal' => 'Afficher les tâches dans le portail client',
    'cancel_schedule' => 'Annuler la planification',
    'scheduled_report' => 'Rapport planifié',
    'scheduled_report_help' => 'Envoyer le rapport :report par courriel comme :format à :email',
    'created_scheduled_report' => 'Rapport planifié avec succès',
    'deleted_scheduled_report' => 'Rapport planifié annulé avec succès',
    'scheduled_report_attached' => 'Votre rapport planifié :type est joint.',
    'scheduled_report_error' => 'Impossible de créer le rapport planifié',
    'invalid_one_time_password' => 'Mot de passe à usage unique invalide',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accepter Apple Pay et Payer avec Google',
    'requires_subdomain' => 'Ce type de paiement nécessite qu\'un :link.',
    'subdomain_is_set' => 'le sous-domaine est défini',
    'verification_file' => 'Fichier de vérification',
    'verification_file_missing' => 'Le fichier de vérification est nécessaire pour accepter les paiements.',
    'apple_pay_domain' => 'Utiliser <code>:domain</code> comme le domaine dans :link.',
    'apple_pay_not_supported' => 'Désolé, Apple/Google Pay n\'est pas supporté par votre navigateur',
    'optional_payment_methods' => 'Méthodes de paiement optionnelles',
    'add_subscription' => 'Ajouter un abonnement',
    'target_url' => 'Cible',
    'target_url_help' => 'Lorsque l\'événement sélectionné advient, l\'app va l\'envoyer à l\'URL spécifiée.',
    'event' => 'Evénement',
    'subscription_event_1' => 'Client créé',
    'subscription_event_2' => 'Facture créée',
    'subscription_event_3' => 'Devis créé',
    'subscription_event_4' => 'Paiement créé',
    'subscription_event_5' => 'Fournisseur créé',
    'subscription_event_6' => 'Devis mis à jour',
    'subscription_event_7' => 'Devis supprimé',
    'subscription_event_8' => 'Facture mise à jour',
    'subscription_event_9' => 'Facture supprimée',
    'subscription_event_10' => 'Client mis à jour',
    'subscription_event_11' => 'Client supprimé',
    'subscription_event_12' => 'Paiement supprimé',
    'subscription_event_13' => 'Fournisseur mis à jour',
    'subscription_event_14' => 'Fournisseur supprimé',
    'subscription_event_15' => 'Dépense créée',
    'subscription_event_16' => 'Dépense mise à jour',
    'subscription_event_17' => 'Dépense supprimée',
    'subscription_event_18' => 'Tâche créée',
    'subscription_event_19' => 'Tâche mise à jour',
    'subscription_event_20' => 'Tâche supprimée',
    'subscription_event_21' => 'Devis approuvé',
    'subscriptions' => 'Abonnements',
    'updated_subscription' => 'Abonnement mis à jour avec succès',
    'created_subscription' => 'Abonnement créé avec succès',
    'edit_subscription' => 'Éditer l\'abonnement',
    'archive_subscription' => 'Archiver l\'abonnement',
    'archived_subscription' => 'Abonnement archivé avec succès',
    'project_error_multiple_clients' => 'Les projets ne peuvent pas appartenir à des clients différents',
    'invoice_project' => 'Facturer le projet',
    'module_recurring_invoice' => 'Factures récurrentes',
    'module_credit' => 'Avoirs',
    'module_quote' => 'Devis & Propositions',
    'module_task' => 'Tâches & Projets',
    'module_expense' => 'Dépenses & Fournisseurs',
    'module_ticket' => 'Tickets',
    'reminders' => 'Rappels',
    'send_client_reminders' => 'Envoyer des courriels de rappels',
    'can_view_tasks' => 'Les tâches sont visibles dans le portail',
    'is_not_sent_reminders' => 'Les rappels ne sont pas envoyés',
    'promotion_footer' => 'Votre promotion expire bientôt, :link pour mettre à jour maintenant.',
    'unable_to_delete_primary' => 'Note : pour supprimer cette société, supprimez tout d\'abord toutes les sociétés liées.',
    'please_register' => 'Veuillez enregistrer votre compte',
    'processing_request' => 'Traitement de la requête',
    'mcrypt_warning' => 'Attention : Mcrypt est déprécié, exécutez :command pour mettre à jour votre chiffrement.',
    'edit_times' => 'Modifier les heures',
    'inclusive_taxes_help' => 'Inclure <b>les taxes dans le coût</b>',
    'inclusive_taxes_notice' => 'Ce paramètre ne peut pas être changé une fois qu\'une facture a été créée.',
    'inclusive_taxes_warning' => 'Attention : les factures existantes devront être réenregistrées',
    'copy_shipping' => 'Copier expédition',
    'copy_billing' => 'Copier facturation',
    'quote_has_expired' => 'Le devis a expiré, veuillez contacter le commerçant.',
    'empty_table_footer' => 'Afficher 0 sur 0 de 0 entrées',
    'do_not_trust' => 'Ne pas se souvenir de cet appareil',
    'trust_for_30_days' => 'Faire confiance pendant 30 jours',
    'trust_forever' => 'Faire confiance pour toujours',
    'kanban' => 'Kanban',
    'backlog' => 'En souffrance',
    'ready_to_do' => 'À faire',
    'in_progress' => 'En cours',
    'add_status' => 'Ajouter un statut',
    'archive_status' => 'Archiver le statut',
    'new_status' => 'Nouveau statut',
    'convert_products' => 'Convertir les produits',
    'convert_products_help' => 'Convertir automatiquement les prix des produits dans la devise du client',
    'improve_client_portal_link' => 'Définir un sous-domaine pour raccourcir le lien du portail client',
    'budgeted_hours' => 'Heures budgétées',
    'progress' => 'Progression',
    'view_project' => 'Voir le projet',
    'summary' => 'Résumé',
    'endless_reminder' => 'Rappel sans fin',
    'signature_on_invoice_help' => 'Ajoutez le code suivant pour afficher la signature de votre client sur le PDF.',
    'signature_on_pdf' => 'Afficher sur le PDF',
    'signature_on_pdf_help' => 'Afficher la signature du client sur la facture / le devis PDF.',
    'expired_white_label' => 'La licence marque blanche a expiré',
    'return_to_login' => 'Retourner à la connexion',
    'convert_products_tip' => 'Note : ajouter un :link nommé ":name" pour voir le taux de change.',
    'amount_greater_than_balance' => 'Le montant est supérieur au solde de la facture, un avoir sera créé avec le montant restant.',
    'custom_fields_tip' => 'Utiliser <code>Etiquette|Option1,Option2</code> pour afficher une boîte de sélection.',
    'client_information' => 'Informations sur le client',
    'updated_client_details' => 'Détails client mis à jour avec succès',
    'auto' => 'Auto',
    'tax_amount' => 'Montant de la taxe',
    'tax_paid' => 'Taxe payée',
    'none' => 'Aucun(e)',
    'proposal_message_button' => 'Pour visionner votre proposition de :amount, cliquez sur le bouton ci-dessous.',
    'proposal' => 'Proposition',
    'proposals' => 'Propositions',
    'list_proposals' => 'Liste des propositions',
    'new_proposal' => 'Nouvelle proposition',
    'edit_proposal' => 'Éditer la proposition',
    'archive_proposal' => 'Archiver la proposition',
    'delete_proposal' => 'Supprimer la proposition',
    'created_proposal' => 'Proposition créée avec succès',
    'updated_proposal' => 'Proposition mise à jour avec succès',
    'archived_proposal' => 'Proposition archivée avec succès',
    'deleted_proposal' => 'Proposition archivée avec succès',
    'archived_proposals' => ':count propositions archivées avec succès',
    'deleted_proposals' => ':count propositions archivées avec succès',
    'restored_proposal' => 'Proposition restaurée avec succès',
    'restore_proposal' => 'Restaurer la proposition',
    'snippet' => 'Extrait',
    'snippets' => 'Extraits',
    'proposal_snippet' => 'Extrait',
    'proposal_snippets' => 'Extraits',
    'new_proposal_snippet' => 'Nouvel extrait',
    'edit_proposal_snippet' => 'Modifier l\'extrait',
    'archive_proposal_snippet' => 'Archiver l\'extrait',
    'delete_proposal_snippet' => 'Supprimer l\'extrait',
    'created_proposal_snippet' => 'Extrait créé avec succès',
    'updated_proposal_snippet' => 'Extrait mis à jour avec succès',
    'archived_proposal_snippet' => 'Extrait archivé avec succès',
    'deleted_proposal_snippet' => 'Extrait supprimé avec succès',
    'archived_proposal_snippets' => ':count extraits archivés avec succès',
    'deleted_proposal_snippets' => ':count extraits supprimés avec succès',
    'restored_proposal_snippet' => 'Extrait restauré avec succès',
    'restore_proposal_snippet' => 'Restaurer l\'extrait',
    'template' => 'Modèle',
    'templates' => 'Modèles',
    'proposal_template' => 'Modèle',
    'proposal_templates' => 'Modèles',
    'new_proposal_template' => 'Nouveau modèle',
    'edit_proposal_template' => 'Éditer le modèle',
    'archive_proposal_template' => 'Archiver le modèle',
    'delete_proposal_template' => 'Supprimer le modèle',
    'created_proposal_template' => 'Modèle créé avec succès',
    'updated_proposal_template' => 'Modèle mise à jour avec succès',
    'archived_proposal_template' => 'Modèle archivé avec succès',
    'deleted_proposal_template' => 'Modèle archivé avec succès',
    'archived_proposal_templates' => ':count modèles archivés avec succès',
    'deleted_proposal_templates' => ':count modèles archivés avec succès',
    'restored_proposal_template' => 'Modèle restauré avec succès',
    'restore_proposal_template' => 'Restaurer le modèle',
    'proposal_category' => 'Catégorie',
    'proposal_categories' => 'Catégories',
    'new_proposal_category' => 'Nouvelle catégorie',
    'edit_proposal_category' => 'Éditer la catégorie',
    'archive_proposal_category' => 'Archiver la catégorie',
    'delete_proposal_category' => 'Supprimer la catégorie',
    'created_proposal_category' => 'Catégorie créée avec succès',
    'updated_proposal_category' => 'Catégorie mise à jour avec succès',
    'archived_proposal_category' => 'Catégorie archivée avec succès',
    'deleted_proposal_category' => 'Catégorie archivée avec succès',
    'archived_proposal_categories' => ':count catégories archivées avec succès',
    'deleted_proposal_categories' => ':count catégories archivées avec succès',
    'restored_proposal_category' => 'Catégorie restaurée avec succès',
    'restore_proposal_category' => 'Restaurer la catégorie',
    'delete_status' => 'Supprimer le statut',
    'standard' => 'Standard',
    'icon' => 'Icône',
    'proposal_not_found' => 'La proposition demandée n\'est pas disponible',
    'create_proposal_category' => 'Créer une catégorie',
    'clone_proposal_template' => 'Dupliquer le modèle',
    'proposal_email' => 'Courriel de proposition',
    'proposal_subject' => 'Nouvelle proposition :number de :account',
    'proposal_message' => 'Pour visionner votre proposition de :amount, cliquez sur le lien ci-dessous.',
    'emailed_proposal' => 'Proposition envoyée par courriel avec succès',
    'load_template' => 'Charger le modèle',
    'no_assets' => 'Aucune image, faites glisser pour envoyer',
    'add_image' => 'Ajouter une image',
    'select_image' => 'Sélectionner une image',
    'upgrade_to_upload_images' => 'Mettre à niveau vers le plan entreprise pour envoyer des images',
    'delete_image' => 'Supprimer l\'image',
    'delete_image_help' => 'Attention : supprimer l\'image la retirera de toutes les propositions.',
    'amount_variable_help' => 'Note: le champ $amount de la facture utilisera le champ partiel/dépôt. Il utilisera le solde de la facture, si spécifié autrement.',
    'taxes_are_included_help' => 'Note : Les taxes incluses ont été activées.',
    'taxes_are_not_included_help' => 'Note : Les taxes incluses ne sont pas activées.',
    'change_requires_purge' => 'Modifier ce paramètre requière de :link les données du compte.',
    'purging' => 'purger',
    'warning_local_refund' => 'Le remboursement sera enregistré dans l\'application, mais NE SERA PAS traité par la passerelle de paiement.',
    'email_address_changed' => 'L\'adresse de courriel a été changée',
    'email_address_changed_message' => 'L\'adresse courriel associée à votre compte a été modifiée de :old_email à :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'L\'exportation vers ZIP nécessite l\'extension GMP',
    'email_history' => 'Historique de courriel',
    'loading' => 'Chargement',
    'no_messages_found' => 'Aucun message trouvé',
    'processing' => 'Traitement',
    'reactivate' => 'Réactiver',
    'reactivated_email' => 'L\'adresse courriel a été réactivée',
    'emails' => 'Courriels',
    'opened' => 'Ouvert(e)',
    'bounced' => 'Rebondi',
    'total_sent' => 'Total envoyé',
    'total_opened' => 'Total ouvert',
    'total_bounced' => 'Total rebondi',
    'total_spam' => 'Total indésirable',
    'platforms' => 'Plateformes',
    'email_clients' => 'Clients courriel',
    'mobile' => 'Mobile',
    'desktop' => 'Bureau',
    'webmail' => 'Webmail',
    'group' => 'Groupe',
    'subgroup' => 'Sous-groupe',
    'unset' => 'Non-défini',
    'received_new_payment' => 'Vous avez reçu un nouveau paiement !',
    'slack_webhook_help' => 'Recevoir des notifications de paiement en utilisant :link.',
    'slack_incoming_webhooks' => 'Crochets web entrants de Slack',
    'accept' => 'Accepter',
    'accepted_terms' => 'Les dernières conditions de service ont été acceptées avec succès.',
    'invalid_url' => 'URL invalide',
    'workflow_settings' => 'Paramètres de flux de travail',
    'auto_email_invoice' => 'Envoyer automatiquement par courriel',
    'auto_email_invoice_help' => 'Envoyer automatiquement par courriel les factures récurrentes lorsqu\'elles sont créés.',
    'auto_archive_invoice' => 'Archiver automatiquement',
    'auto_archive_invoice_help' => 'Archiver automatiquement les factures lorsqu\'elles sont payées.',
    'auto_archive_quote' => 'Archiver automatiquement',
    'auto_archive_quote_help' => 'Archiver automatiquement les devis lorsqu\'ils sont convertis.',
    'require_approve_quote' => 'Demande d\'approbation du devis',
    'require_approve_quote_help' => 'Exiger des clients qu\'ils approuvent les devis.',
    'allow_approve_expired_quote' => 'Autoriser l\'approbation des devis expirés',
    'allow_approve_expired_quote_help' => 'Autoriser les clients à approuver les devis expirés.',
    'invoice_workflow' => 'Flux de travail de facture',
    'quote_workflow' => 'Flux de travail de devis',
    'client_must_be_active' => 'Erreur : le client doit être actif',
    'purge_client' => 'Purger le client',
    'purged_client' => 'Client purgé avec succès',
    'purge_client_warning' => 'Tous les enregistrements associés (factures, tâches, dépenses, documents, ...) seront également supprimés.',
    'clone_product' => 'Dupliquer le produit',
    'item_details' => 'Détails de l\'article',
    'send_item_details_help' => 'Envoyer les détails de l\'article de la ligne à la passerelle de paiement.',
    'view_proposal' => 'Voir la proposition',
    'view_in_portal' => 'Voir dans le portail',
    'cookie_message' => 'Ce site Web utilise des cookies pour vous assurer la meilleure expérience sur notre site Web.',
    'got_it' => 'J\'ai compris !',
    'vendor_will_create' => 'fournisseur sera créé',
    'vendors_will_create' => 'fournisseurs seront créés',
    'created_vendors' => ':count fournisseur(s) créé(s) avec succès',
    'import_vendors' => 'Importer des fournisseurs',
    'company' => 'Entreprise',
    'client_field' => 'Champ de client',
    'contact_field' => 'Champ de contact',
    'product_field' => 'Champ de produit',
    'task_field' => 'Champ de tâche',
    'project_field' => 'Champ de projet',
    'expense_field' => 'Champ de dépense',
    'vendor_field' => 'Champ de fournisseur',
    'company_field' => 'Champ d\'entreprise',
    'invoice_field' => 'Champ de facture',
    'invoice_surcharge' => 'Majoration de facture',
    'custom_task_fields_help' => 'Ajouter un champ lors de la création d\'une tâche.',
    'custom_project_fields_help' => 'Ajouter un champ lors de la création d\'un projet.',
    'custom_expense_fields_help' => 'Ajouter un champ lors de la création d\'une dépense.',
    'custom_vendor_fields_help' => 'Ajouter un champ lors de la création d\'un fournisseur.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Facture impayée',
    'paid_invoice' => 'Facture payée',
    'unapproved_quote' => 'Devis non-approuvé',
    'unapproved_proposal' => 'Proposition non-approuvée',
    'autofills_city_state' => 'Remplit automatiquement la ville/l\'état',
    'no_match_found' => 'Aucune correspondance trouvée',
    'password_strength' => 'Force du mot de passe',
    'strength_weak' => 'Faible',
    'strength_good' => 'Bonne',
    'strength_strong' => 'Forte',
    'mark' => 'Marquer',
    'updated_task_status' => 'Statut de tâche mis à jour avec succès',
    'background_image' => 'Image d\'arrière-plan',
    'background_image_help' => 'Utiliser le :link pour gérer vos images, nous recommandons d\'utiliser un petit fichier.',
    'proposal_editor' => 'éditeur de proposition',
    'background' => 'Arrière-plan',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Article de frais de passerelle',
    'gateway_fee_description' => 'Majoration de frais de passerelle',
    'gateway_fee_discount_description' => 'Réduction de frais de passerelle',
    'show_payments' => 'Montrer les paiements',
    'show_aging' => 'Montrer le vieillissement',
    'reference' => 'Référence',
    'amount_paid' => 'Montant payé',
    'send_notifications_for' => 'Envoyer des notifications pour',
    'all_invoices' => 'Toutes les factures',
    'my_invoices' => 'Mes factures',
    'payment_reference' => 'Référence de paiement',
    'maximum' => 'Maximum',
    'sort' => 'Trier',
    'refresh_complete' => 'Rafraichissement terminé',
    'please_enter_your_email' => 'Entrez votre adresse e-mail',
    'please_enter_your_password' => 'Entez votre mot de passe',
    'please_enter_your_url' => 'Entrez votre URL',
    'please_enter_a_product_key' => 'Entrez la clé produit',
    'an_error_occurred' => 'Une erreur s\'est produite',
    'overview' => 'Vue d\'ensemble',
    'copied_to_clipboard' => ':value a été copié au presse-papier',
    'error' => 'Erreur',
    'could_not_launch' => 'Lancement impossible',
    'additional' => 'Additionnel',
    'ok' => 'Ok',
    'email_is_invalid' => 'L\'adresse de courriel n\'est pas correcte',
    'items' => 'Articles ',
    'partial_deposit' => 'Depot Partial ',
    'add_item' => 'Ajouter Article ',
    'total_amount' => 'Montant Total ',
    'pdf' => 'Fichier PDF',
    'invoice_status_id' => 'Etat de Facture',
    'click_plus_to_add_item' => 'Cliquer pour ajouter un article (objet)',
    'count_selected' => 'nombre selectionne ',
    'dismiss' => 'Quitter',
    'please_select_a_date' => 'Sélectionnez une date',
    'please_select_a_client' => 'Sélectionnez un client',
    'language' => 'Langue',
    'updated_at' => 'Mis à jour',
    'please_enter_an_invoice_number' => 'Sélectionnez un numéro de facture',
    'please_enter_a_quote_number' => 'Sélectionner un numéro de devis',
    'clients_invoices' => 'factures de :client',
    'viewed' => 'Vu',
    'approved' => 'Approuvé',
    'invoice_status_1' => 'Brouillon ',
    'invoice_status_2' => 'Envoye',
    'invoice_status_3' => 'Vue',
    'invoice_status_4' => 'Approuvé',
    'invoice_status_5' => 'Partial ',
    'invoice_status_6' => 'Payé',
    'marked_invoice_as_sent' => 'Facture marquee comme envoyee avec succes',
    'please_enter_a_client_or_contact_name' => 'Veuillez introduire un nom de client',
    'restart_app_to_apply_change' => 'Recommencer k\'app pour introduire l\'app change',
    'refresh_data' => 'Rafraîchir les données ',
    'blank_contact' => 'Details pour contacter la Banque ',
    'no_records_found' => 'Pas d\'archives trouves ',
    'industry' => 'Champ',
    'size' => 'Taille ',
    'net' => 'Net',
    'show_tasks' => 'Afficher des taches',
    'email_reminders' => 'Messages de rappel par courriel ',
    'reminder1' => 'Premier Message de Rappel ',
    'reminder2' => 'Deuxieme Message de Rappel ',
    'reminder3' => 'Troisieme Message de Rappel ',
    'send' => 'Envoyer ',
    'auto_billing' => 'Debit Automatique ',
    'button' => 'Bouton ',
    'more' => 'Plus',
    'edit_recurring_invoice' => 'Editer facture récurrente',
    'edit_recurring_quote' => 'Editer devis récurrent',
    'quote_status' => 'État du devis',
    'please_select_an_invoice' => 'Sélectionnez une facture',
    'filtered_by' => 'Filtré par',
    'payment_status' => 'État du paiement',
    'payment_status_1' => 'En attente',
    'payment_status_2' => 'Annulé',
    'payment_status_3' => 'Échoué',
    'payment_status_4' => 'Complété',
    'payment_status_5' => 'Partiellement remboursé',
    'payment_status_6' => 'Remboursement',
    'send_receipt_to_client' => 'Envoyer le reçu au client',
    'refunded' => 'Remboursé',
    'marked_quote_as_sent' => 'Le devis sélectionné a été envoyé avec succès',
    'custom_module_settings' => 'Paramètres personnalisés de modules',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Numéro de ticket',
    'new_ticket' => 'Nouveau ticket',
    'edit_ticket' => 'Mettre à jour le ticket',
    'view_ticket' => 'Voir le ticket',
    'archive_ticket' => 'Archiver le ticket',
    'restore_ticket' => 'Restaurer le ticket',
    'delete_ticket' => 'Supprimer le ticket',
    'archived_ticket' => 'Ticket archivé avec succès',
    'archived_tickets' => 'Tickets archivés avec succès',
    'restored_ticket' => 'Ticket restauré avec succès',
    'deleted_ticket' => 'Ticket supprimé avec succès',
    'open' => 'Ouvrir',
    'new' => 'Nouveau',
    'closed' => 'Fermé',
    'reopened' => 'Ré-ouvrir',
    'priority' => 'Prioritée',
    'last_updated' => 'Dernière mise à jour',
    'comment' => 'Commentaire',
    'tags' => 'Tags',
    'linked_objects' => 'Objets liés',
    'low' => 'Faible',
    'medium' => 'Moyen',
    'high' => 'Élevé',
    'no_due_date' => 'Pas de date d\'échéance enregistrée',
    'assigned_to' => 'Assigné à',
    'reply' => 'Répondre',
    'awaiting_reply' => 'Attente de réponse',
    'ticket_close' => 'Fermer le ticket',
    'ticket_reopen' => 'Ré-ouvrir le ticket',
    'ticket_open' => 'Ouvrir un ticket',
    'ticket_split' => 'Diviser le ticket',
    'ticket_merge' => 'Fusionner les tickets',
    'ticket_update' => 'Mettre à jour le ticket',
    'ticket_settings' => 'Paramètres du ticket',
    'updated_ticket' => 'Ticket mis à jour',
    'mark_spam' => 'Indiqué comme spam',
    'local_part' => 'Partie locale',
    'local_part_unavailable' => 'Nom pris',
    'local_part_available' => 'Nom disponible',
    'local_part_invalid' => 'Nom invalide (alphanumérique seulement, aucun espace',
    'local_part_help' => 'Personnalisez la partie locale de votre support par courriel, ex. VOTRE_NOM@support.invoiceninja.com',
    'from_name_help' => 'DE est l\'expéditeur reconnu qui est affiché au lieu de l\'adresse courriel, ex. Centre de soutien',
    'local_part_placeholder' => 'VOTRE_NOM',
    'from_name_placeholder' => 'Centre de Support',
    'attachments' => 'Pièces jointes',
    'client_upload' => 'Envois des clients',
    'enable_client_upload_help' => 'Permettre aux clients d\'envoyer des documents/pièces jointes',
    'max_file_size_help' => 'La taille maximale de fichiers (KO) est limitée par les variables post_max_size et upload_max_filesize dans votre PHP.INI',
    'max_file_size' => 'Taille maximale des fichiers',
    'mime_types' => 'Type MIME',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Liste séparée par une virgule pour les types MIME autorisés. Laissant vide pour tout autoriser',
    'ticket_number_start_help' => 'Le numéro du billet doit être plus grand que le billet en cours',
    'new_ticket_template_id' => 'Nouveau ticket',
    'new_ticket_autoresponder_help' => 'En sélectionnant un modèle, une réponse automatique sera envoyée à un client/contact lorsqu\'un nouveau ticket est créé',
    'update_ticket_template_id' => 'Ticket mis à jour',
    'update_ticket_autoresponder_help' => 'En sélectionnant un modèle, une réponse automatique sera envoyée à un client/contact lorsqu\'un ticket est mis à jour',
    'close_ticket_template_id' => 'Fermer le ticket',
    'close_ticket_autoresponder_help' => 'En sélectionnant un modèle, une réponse automatique sera envoyée à un client/contact lorsqu\'un ticket est fermé',
    'default_priority' => 'Priorité par défaut',
    'alert_new_comment_id' => 'Nouveau commentaire',
    'alert_comment_ticket_help' => 'En sélectionnant un modèle, une notification (à l\'agent) sera envoyée lorsqu\'un commentaire est posté',
    'alert_comment_ticket_email_help' => 'Courriels séparés par une virgule pour CCI sur un nouveau commentaire.',
    'new_ticket_notification_list' => 'Notification de nouveaux tickets additionnel',
    'update_ticket_notification_list' => 'Notification de nouveau comment additionnel',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Assignation de ticket',
    'alert_ticket_assign_agent_id_hel' => 'En sélectionnant un modèle, une notification (à l\'agent) sera envoyée lorsqu\'un billet est assigné.',
    'alert_ticket_assign_agent_id_notifications' => 'Notification d\'assignation de ticket additionnel',
    'alert_ticket_assign_agent_id_help' => 'Courriels séparés par une virgule pour CCI pour un billet assigné.',
    'alert_ticket_transfer_email_help' => 'Courriels séparés par une virgule pour CCI sur un billet transféré.',
    'alert_ticket_overdue_agent_id' => 'Ticket en retard.',
    'alert_ticket_overdue_email' => 'Notifications de billets en retard additionnels',
    'alert_ticket_overdue_email_help' => 'Courriels séparés par une virgule pour CCI sur un ticket en retard.',
    'alert_ticket_overdue_agent_id_help' => 'En sélectionnant un modèle, une notification (à l\'agent) sera envoyée lorsqu\'un ticket est en retard.',
    'ticket_master' => 'Ticket maitre',
    'ticket_master_help' => 'Peut assigner et transférer les tickets. Assigné par défaut pour tous les tickets.',
    'default_agent' => 'Agent par défaut',
    'default_agent_help' => 'Cette sélection va automatiquement être assignée à tous les courriels entrants',
    'show_agent_details' => 'Afficher les informations de l\'agent dans les réponses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Enlever l\'avatar',
    'ticket_not_found' => 'Ticket non trouvé',
    'add_template' => 'Ajouter un modèle',
    'ticket_template' => 'Modèle de ticket',
    'ticket_templates' => 'Modèles de ticket',
    'updated_ticket_template' => 'Modèle de ticket mis à jour',
    'created_ticket_template' => 'Modèle de ticket crée',
    'archive_ticket_template' => 'Archiver modèle',
    'restore_ticket_template' => 'Restaurer modèle',
    'archived_ticket_template' => 'Modèle archivé avec succès',
    'restored_ticket_template' => 'Modèle restaurer avec succès',
    'close_reason' => 'Faites nous savoir pourquoi vous fermez ce ticket',
    'reopen_reason' => 'Faites nous savoir pourquoi vous ré-ouvrez ce ticket',
    'enter_ticket_message' => 'Entrez un message pour mettre à jour le ticket',
    'show_hide_all' => 'Afficher / Masquer tout',
    'subject_required' => 'Sujet requis',
    'mobile_refresh_warning' => 'Si vous utilisez l\'app mobile, vous devez faire une actualisation complète.',
    'enable_proposals_for_background' => 'Pour envoyer une image de fond :link pour activer le module de propositions.',
    'ticket_assignment' => 'Le ticket :ticket_number a été assigné à :agent',
    'ticket_contact_reply' => 'Le ticket :ticket_number a été mis à jour par le client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number a été crée.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number a été mis à jour.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number a été fermé.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number est maintenant arriéré.',
    'merge' => 'Fusionner',
    'merged' => 'Fusionné',
    'agent' => 'Agent',
    'parent_ticket' => 'Ticket parent',
    'linked_tickets' => 'Ticket lié',
    'merge_prompt' => 'Entrez un numéro de ticket pour fusionner avec',
    'merge_from_to' => 'Le ticket #:old_ticket a été fusionné avec le ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Le ticket #:old_ticket a été fermé et fusionner dans le ticket #:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Le ticket #:old_ticket a été fermé et fusionner dans ce ticket',
    'merge_placeholder' => 'Fusionner le ticket #:ticket dans le ticket suivant',
    'select_ticket' => 'Sélectionner un ticket',
    'new_internal_ticket' => 'Nouveau ticket interne',
    'internal_ticket' => 'Ticket interne',
    'create_ticket' => 'Créer un ticket',
    'allow_inbound_email_tickets_external' => 'Nouveaux tickets par courriel (Client)',
    'allow_inbound_email_tickets_external_help' => 'Permettre aux clients de créer des nouveaux tickets par courriel',
    'include_in_filter' => 'Inclure dans le filtre',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Comparer',
    'hosted_login' => 'Authentification Hosted',
    'selfhost_login' => 'Authentification Selfhost',
    'google_login' => 'Authentification Google',
    'thanks_for_patience' => 'Merci de votre patience pendant l\'implémentation de ces fonctionnalités.\n\nNous espérons terminer dans les prochains mois.\n\nD\'ici là, nous continuerons le support de',
    'legacy_mobile_app' => 'Ancienne App mobile',
    'today' => 'Aujourd\'hui',
    'current' => 'Actuel',
    'previous' => 'Précédent',
    'current_period' => 'Période actuelle',
    'comparison_period' => 'Comparaison de période',
    'previous_period' => 'Période précédente',
    'previous_year' => 'Année précédente',
    'compare_to' => 'Comparer à',
    'last_week' => 'Semaine dernière',
    'clone_to_invoice' => 'Dupliquer la facture',
    'clone_to_quote' => 'Dupliquer en devis',
    'convert' => 'Convertir',
    'last7_days' => '7 derniers jours',
    'last30_days' => '30 derniers jours',
    'custom_js' => 'JS personnalisé',
    'adjust_fee_percent_help' => 'Ajuster le frais de pourcentage au compte',
    'show_product_notes' => 'Afficher les détails des produits',
    'show_product_notes_help' => 'Afficher la <b>description et le prix</b> dans le sélecteur de produits',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Merci d\'utiliser notre app !',
    'if_you_like_it' => 'Si vous appréciez, merci de ',
    'to_rate_it' => 'pour évaluer notre app.',
    'average' => 'Moyenne',
    'unapproved' => 'Non approuvé',
    'authenticate_to_change_setting' => 'Veuillez vous connecter pour changer ce paramètre',
    'locked' => 'Verrouillé',
    'authenticate' => 'Connexion',
    'please_authenticate' => 'Veuillez vous connecter',
    'biometric_authentication' => 'Connexion biométrique',
    'auto_start_tasks' => 'Démarrer automatiquement les tâches',
    'budgeted' => 'Budgétisé',
    'please_enter_a_name' => 'Veuillez entrer un nom',
    'click_plus_to_add_time' => 'Cliquez sur + pour ajouter du temps',
    'design' => 'Design',
    'password_is_too_short' => 'Mot de passe trop court',
    'failed_to_find_record' => 'Élément non trouvé',
    'valid_until_days' => 'Ισχύει Μέχρι',
    'valid_until_days_help' => 'Ρυθμίζει αυτόματα το 1 Ισχύει Μέχρι το 1 η τιμή στις προσφορές σε αυτό για πολλές μέρες στο μέλλον. Αφήστε καινό για απενεργοποίηση.',
    'usually_pays_in_days' => 'Jours',
    'requires_an_enterprise_plan' => 'Χρειάζεται πλάνο επιχείρησης',
    'take_picture' => 'Φωτογραφίσετε ',
    'upload_file' => 'Envoyer un fichier',
    'new_document' => 'Νέο Έγγραφο ',
    'edit_document' => 'Εκδώσετε Έγγραφο ',
    'uploaded_document' => 'Le document a été envoyé avec succès',
    'updated_document' => 'Document mis à jour avec succès',
    'archived_document' => 'Document archivé avec succès',
    'deleted_document' => 'Le document a été supprimé avec succès',
    'restored_document' => 'Le document a été restauré avec succès',
    'no_history' => 'Κανένα Ιστορικό',
    'expense_status_1' => 'Σύνδεση',
    'expense_status_2' => 'Σε εκκρεμότητα',
    'expense_status_3' => 'Με τιμολόγιο',
    'no_record_selected' => 'Aucun enregistrement sélectionné',
    'error_unsaved_changes' => 'Veuillez enregistrer ou annuler vos modifications',
    'thank_you_for_your_purchase' => 'Merci pour votre achat !',
    'redeem' => 'Rembourser',
    'back' => 'Retour',
    'past_purchases' => 'Achats antérieurs',
    'annual_subscription' => 'Abonnement annuel',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count utilisateur(s)',
    'upgrade' => 'Mettre à niveau',
    'please_enter_a_first_name' => 'Veuillez entrer un prénom',
    'please_enter_a_last_name' => 'Veuillez entrer un nom',
    'please_agree_to_terms_and_privacy' => 'Veuillez accepter les conditions d\'utilisation et la politique de confidentialité pour créer un compte.',
    'i_agree_to_the' => 'J\'accepte les',
    'terms_of_service_link' => 'Conditions d\'utilisation',
    'privacy_policy_link' => 'Politique de confidentialité',
    'view_website' => 'Voir le site Web',
    'create_account' => 'Créer un compte',
    'email_login' => 'Email de connexion',
    'late_fees' => 'Frais de retard',
    'payment_number' => 'Numéro de paiement',
    'before_due_date' => 'Avant la date d\'échéance',
    'after_due_date' => 'Après la date d\'échéance',
    'after_invoice_date' => 'Après la date de facturation',
    'filtered_by_user' => 'Filtré par utilisateur',
    'created_user' => 'Utilisateur créé avec succès avec succès',
    'primary_font' => 'Police principale',
    'secondary_font' => 'Police secondaire',
    'number_padding' => 'Marge interne du nombre',
    'general' => 'Général',
    'surcharge_field' => 'Champ Surcharge',
    'company_value' => 'Valeur de compagnie',
    'credit_field' => 'Champ de Crédit',
    'payment_field' => 'Champ de Paiement',
    'group_field' => 'Champ de Groupe',
    'number_counter' => 'Compteur de nombre',
    'number_pattern' => 'Modèle de nombre',
    'custom_javascript' => 'JavaScript personnalisé',
    'portal_mode' => 'Mode portail',
    'attach_pdf' => 'Joindre PDF',
    'attach_documents' => 'Joindre les Documents',
    'attach_ubl' => 'Joindre UBL',
    'email_style' => 'Style d\'email',
    'processed' => 'Traité',
    'fee_amount' => 'Montant des frais',
    'fee_percent' => 'Pourcentage des frais',
    'fee_cap' => 'Limite des frais',
    'limits_and_fees' => 'Limites/Frais',
    'credentials' => 'Identifiants',
    'require_billing_address_help' => 'Le client doit fournir son adresse de facturation',
    'require_shipping_address_help' => 'Le client doit fournir son adresse de livraison',
    'deleted_tax_rate' => 'Le taux de taxe a été supprimé avec succès',
    'restored_tax_rate' => 'Le taux de taxe a été restauré avec succès',
    'provider' => 'Fournisseur',
    'company_gateway' => 'Passerelle de paiement',
    'company_gateways' => 'Passerelles de paiements',
    'new_company_gateway' => 'Nouvelle passerelle',
    'edit_company_gateway' => 'Éditer la passerelle',
    'created_company_gateway' => 'La passerelle a été créée avec succès',
    'updated_company_gateway' => 'La passerelle a été mise à jour avec succès',
    'archived_company_gateway' => 'La passerelle a été archivée avec succès',
    'deleted_company_gateway' => 'La passerelle a été supprimée avec succès',
    'restored_company_gateway' => 'La passerelle a été restaurée avec succès',
    'continue_editing' => 'Continuer l\'édition',
    'default_value' => 'Valeur Par Défaut',
    'currency_format' => 'Format de devise',
    'first_day_of_the_week' => 'Premier Jour de la Semaine',
    'first_month_of_the_year' => 'Premier mois de l\'Année',
    'symbol' => 'Symbole',
    'ocde' => 'Code',
    'date_format' => 'Format de la date',
    'datetime_format' => 'Format date/heure',
    'send_reminders' => 'Envoyer des rappels',
    'timezone' => 'Fuseau horaire',
    'filtered_by_group' => 'Filtrer par groupe',
    'filtered_by_invoice' => 'Filtré par Facture',
    'filtered_by_client' => 'Filtré par Client',
    'filtered_by_vendor' => 'Filtré par Vendeur',
    'group_settings' => 'Paramètres de groupe',
    'groups' => 'Groupes',
    'new_group' => 'Nouveau Groupe',
    'edit_group' => 'Éditer le groupe',
    'created_group' => 'Le groupe a été créé avec succès',
    'updated_group' => 'Le groupe a été mis à jour avec succès',
    'archived_group' => 'Le groupe a été archivé avec succès',
    'deleted_group' => 'Le groupe a été supprimé avec succès',
    'restored_group' => 'Le groupe a été restauré avec succès',
    'upload_logo' => 'Envoyer le logo',
    'uploaded_logo' => 'Le logo a été envoyé avec succès',
    'saved_settings' => 'Les paramètres ont été sauvegardés avec succès',
    'device_settings' => 'Paramètres de l\'appareil',
    'credit_cards_and_banks' => 'Cartes de crédit et banques',
    'price' => 'Prix',
    'email_sign_up' => 'Inscription par email',
    'google_sign_up' => 'Inscription avec Google',
    'sign_up_with_google' => 'Inscrivez-vous avec Google',
    'long_press_multiselect' => 'Multisélection par pression longue',
    'migrate_to_next_version' => 'Migrer dans la nouvelle version d\'Invoice Ninja.',
    'migrate_intro_text' => 'Nous avons travaillé sur une nouvelle version de Invoice Ninja. Cliquez sur le bouton ci-dessous pour démarrer la migration.',
    'start_the_migration' => 'Démarrer la migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Bienvenue dans la nouvelle version d\'Invoice Ninja',
    'next_step_data_download' => 'Lors de la prochaine étape, nous pourrez télécharger vos données pour la migration.',
    'download_data' => 'Pressez le bouton ci-dessous pour downloader les données.',
    'migration_import' => 'Parfait! Vous êtes prêt à importer vos données. Rendez-vous dans la nouvelle instance pour lancer l\'importation.',
    'continue' => 'Continuer',
    'company1' => 'Champ personnalisé Entreprise 1',
    'company2' => 'Champ personnalisé Entreprise 2',
    'company3' => 'Champ personnalisé Entreprise 3',
    'company4' => 'Champ personnalisé Entreprise 4',
    'product1' => 'Champ personnalisé Produit 1',
    'product2' => 'Champ personnalisé Produit 2',
    'product3' => 'Champ personnalisé Produit 3',
    'product4' => 'Champ personnalisé Produit 4',
    'client1' => 'Champ personnalisé Client 1',
    'client2' => 'Client personnalisé 2',
    'client3' => 'Client personnalisé 3',
    'client4' => 'Client personnalisé 4',
    'contact1' => 'Champ personnalisé Contact 1',
    'contact2' => 'Champ personnalisé Contact 2',
    'contact3' => 'Champ personnalisé Contact 3',
    'contact4' => 'Champ personnalisé Contact 4',
    'task1' => 'Champ personnalisé Tâche 1',
    'task2' => 'Champ personnalisé Tâche 2',
    'task3' => 'Champ personnalisé Tâche 3',
    'task4' => 'Champ personnalisé Tâche 4',
    'project1' => 'Champ personnalisé Projet 1',
    'project2' => 'Champ personnalisé Projet 2',
    'project3' => 'Champ personnalisé Projet 3',
    'project4' => 'Champ personnalisé Projet 4',
    'expense1' => 'Champ personnalisé Dépense 1',
    'expense2' => 'Champ personnalisé Dépense 2',
    'expense3' => 'Champ personnalisé Dépense 3',
    'expense4' => 'Champ personnalisé Dépense 4',
    'vendor1' => 'Fournisseur personnalisé 1',
    'vendor2' => 'Fournisseur personnalisé 2',
    'vendor3' => 'Fournisseur personnalisé 3',
    'vendor4' => 'Fournisseur personnalisé 4',
    'invoice1' => 'Champ personnalisé Facture 1',
    'invoice2' => 'Champ personnalisé Facture 2',
    'invoice3' => 'Champ personnalisé Facture 3',
    'invoice4' => 'Champ personnalisé Facture 4',
    'payment1' => 'Champ personnalisé Paiement 1',
    'payment2' => 'Champ personnalisé Paiement 2',
    'payment3' => 'Champ personnalisé Paiement 3',
    'payment4' => 'Champ personnalisé Paiement 4',
    'surcharge1' => 'Autre frais 1',
    'surcharge2' => 'Autre frais 2',
    'surcharge3' => 'Autre frais 3',
    'surcharge4' => 'Autre frais 4',
    'group1' => 'Champ personnalisé Groupe 1',
    'group2' => 'Champ personnalisé Groupe 2',
    'group3' => 'Champ personnalisé Groupe 3',
    'group4' => 'Champ personnalisé Groupe 4',
    'number' => 'Nombre',
    'count' => 'Compte',
    'is_active' => 'Actif',
    'contact_last_login' => 'Dernière connexion du contact',
    'contact_full_name' => 'Nom du contact',
    'contact_custom_value1' => 'Valeur champ personnalisé Contact 1',
    'contact_custom_value2' => 'Valeur champ personnalisé Contact 2',
    'contact_custom_value3' => 'Valeur champ personnalisé Contact 3',
    'contact_custom_value4' => 'Valeur champ personnalisé Contact 4',
    'assigned_to_id' => 'Assigné à ID',
    'created_by_id' => 'Créé par ID',
    'add_column' => 'Ajouter une colonne',
    'edit_columns' => 'Éditer les colonnes',
    'to_learn_about_gogle_fonts' => 'En savoir plus sur Google Fonts',
    'refund_date' => 'Date du remboursement',
    'multiselect' => 'Sélection multiple',
    'verify_password' => 'Vérifier le mot de passe',
    'applied' => 'Publié',
    'include_recent_errors' => 'Contient les erreurs récentes des journaux',
    'your_message_has_been_received' => 'Nous avons reçu votre message et répondrons dans les meilleurs délais',
    'show_product_details' => 'Voir les détails du produit',
    'show_product_details_help' => 'Veuillez inclure la description et le coût dans la liste déroulante du produit',
    'pdf_min_requirements' => 'Le générateur de PDF nécessite la version :version',
    'adjust_fee_percent' => 'Ajuster le pourcentage de frais',
    'configure_settings' => 'Modifier les paramètres',
    'about' => 'À propos',
    'credit_email' => 'Courriel de crédit',
    'domain_url' => 'URL du domaine',
    'password_is_too_easy' => 'Le mot de passe doit comporter au moins une majuscule et un nombre',
    'client_portal_tasks' => 'Tâche du portail client',
    'client_portal_dashboard' => 'Tableau de bord du portail client',
    'please_enter_a_value' => 'Saisissez une valeur',
    'deleted_logo' => 'Le logo a été supprimé',
    'generate_number' => 'Générer un nombre',
    'when_saved' => 'Lors de la sauvegarde',
    'when_sent' => 'Lors de l\'envoi',
    'select_company' => 'Sélectionner une entreprise',
    'float' => 'Flottant',
    'collapse' => 'Réduire',
    'show_or_hide' => 'Afficher/cacher',
    'menu_sidebar' => 'Barre latérale du menu',
    'history_sidebar' => 'Historique latéral',
    'tablet' => 'Tablette',
    'layout' => 'Présentation',
    'module' => 'Module',
    'first_custom' => 'Premier personnalisé',
    'second_custom' => 'Second personnalisé',
    'third_custom' => 'Troisième personnalisé',
    'show_cost' => 'Voir le coût',
    'show_cost_help' => 'Afficher un champ coût du produit pour suivre la marge',
    'show_product_quantity' => 'Voir la quantité du produit',
    'show_product_quantity_help' => 'Afficher un champ de quantité du produit, sinon en choisir un par défaut',
    'show_invoice_quantity' => 'Voir la quantité sur la facture',
    'show_invoice_quantity_help' => 'Afficher un champ de quantité pour la position, sinon en choisir un par défaut',
    'default_quantity' => 'Quantité par défaut',
    'default_quantity_help' => 'Mettre automatiquement la quantité de la position à un',
    'one_tax_rate' => 'Un taux de taxe',
    'two_tax_rates' => 'Deux taux de taxe',
    'three_tax_rates' => 'Trois taux de taxe',
    'default_tax_rate' => 'Taux de taxe par défaut',
    'invoice_tax' => 'Taxe de la facture',
    'line_item_tax' => 'Taxe de la position',
    'inclusive_taxes' => 'Taxes incluses',
    'invoice_tax_rates' => 'Taux de taxe de la facture',
    'item_tax_rates' => 'Taux de taxe de la position',
    'configure_rates' => 'Configurer les taux',
    'tax_settings_rates' => 'Taux de taxes',
    'accent_color' => 'Couleur de mise en évidence',
    'comma_sparated_list' => 'Liste séparée par des virgules',
    'single_line_text' => 'Texte sur une ligne',
    'multi_line_text' => 'Texte multi-lignes',
    'dropdown' => 'Liste déroulante',
    'field_type' => 'Type du champ',
    'recover_password_email_sent' => 'Un courriel de récupération du mot de passe a été envoyé',
    'removed_user' => 'L\'utilisateur a été supprimé',
    'freq_three_years' => 'Trois ans',
    'military_time_help' => 'Affichage sur 24h',
    'click_here_capital' => 'Cliquer ici',
    'marked_invoice_as_paid' => 'Facture marquée comme envoyée',
    'marked_invoices_as_sent' => 'Les factures ont été marquées envoyées',
    'marked_invoices_as_paid' => 'Factures marquées comme envoyées',
    'activity_57' => 'La facture :invoice n\'a pu être envoyée',
    'custom_value3' => 'Valeur personnalisée 3',
    'custom_value4' => 'Valeur personnalisée 4',
    'email_style_custom' => 'Style de courriel personnalisé',
    'custom_message_dashboard' => 'Message personnalisé du tableau de bord',
    'custom_message_unpaid_invoice' => 'Message personnalisé pour une facture impayée',
    'custom_message_paid_invoice' => 'Message personnalisé pour un paiement de facture',
    'custom_message_unapproved_quote' => 'Message personnalisé pour un devis refusé',
    'lock_sent_invoices' => 'Verrouiller les factures envoyées',
    'translations' => 'Traductions',
    'task_number_pattern' => 'Modèle de numéro de tâche',
    'task_number_counter' => 'Modèle de compteur de tâche',
    'expense_number_pattern' => 'Modèle de numéro de dépense',
    'expense_number_counter' => 'Modèle de compteur de dépense',
    'vendor_number_pattern' => 'Modèle de numéro de fournisseur',
    'vendor_number_counter' => 'Modèle de compteur de fournisseur',
    'ticket_number_pattern' => 'Modèle de numéro de ticket',
    'ticket_number_counter' => 'Modèle de compteur de ticket',
    'payment_number_pattern' => 'Modèle de numéro de paiement',
    'payment_number_counter' => 'Modèle de compteur de paiement',
    'invoice_number_pattern' => 'Modèle de numéro de facture',
    'quote_number_pattern' => 'Modèle de numéro de devis',
    'client_number_pattern' => 'Modèle de numéro de crédit',
    'client_number_counter' => 'Modèle de compteur de crédit',
    'credit_number_pattern' => 'Modèle de numéro de crédit',
    'credit_number_counter' => 'Modèle de compteur de crédit',
    'reset_counter_date' => 'Remise à zéro du compteur de date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Nom par défaut de la taxe 1',
    'default_tax_rate_1' => 'Taux par défaut de la taxe 1',
    'default_tax_name_2' => 'Nom par défaut de la taxe 2',
    'default_tax_rate_2' => 'Taux par défaut de la taxe 2',
    'default_tax_name_3' => 'Nom par défaut de la taxe 3',
    'default_tax_rate_3' => 'Taux par défaut de la taxe 3',
    'email_subject_invoice' => 'Sujet du courriel de la facture',
    'email_subject_quote' => 'Sujet du courriel du devis',
    'email_subject_payment' => 'Sujet du courriel du paiement',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Ville du client',
    'client_state' => 'Région du client',
    'client_country' => 'Pays du client',
    'client_is_active' => 'Le client est actif',
    'client_balance' => 'Solde du client',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Taux de taxe 1',
    'tax_rate2' => 'Taux de taxe 2',
    'tax_rate3' => 'Taux de taxe 3',
    'archived_at' => 'Archivé le',
    'has_expenses' => 'Dépenses en cours',
    'custom_taxes1' => 'Autres taxes 1',
    'custom_taxes2' => 'Autres taxes 2',
    'custom_taxes3' => 'Autres taxes 3',
    'custom_taxes4' => 'Autres taxes 4',
    'custom_surcharge1' => 'Autre frais 1',
    'custom_surcharge2' => 'Autre frais 2',
    'custom_surcharge3' => 'Autre frais 3',
    'custom_surcharge4' => 'Autre frais 4',
    'is_deleted' => 'Supprimé',
    'vendor_city' => 'Ville du fournisseur',
    'vendor_state' => 'Région du fournisseur',
    'vendor_country' => 'Pays du fournisseur',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'L\'entreprise a été ajoutée',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optionnel',
    'license' => 'Licence',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
